/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_FL3NGR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_FL3NGR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_FL3NGR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FL3NGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FL3NGR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_FL3NGR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FL3NGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FL3NGR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_FL3NGR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_FL3NGR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_FL3NGR::Heavy_WSTD_FL3NGR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_jurx6EIB);
  numBytes += sLine_init(&sLine_EUmf9ANc);
  numBytes += sLine_init(&sLine_RuzPx7Z9);
  numBytes += sLine_init(&sLine_FrngpOrg);
  numBytes += sLine_init(&sLine_SVa9Anlu);
  numBytes += sBiquad_init(&sBiquad_s_YVqHOVm7);
  numBytes += sLine_init(&sLine_41u3hJH9);
  numBytes += sLine_init(&sLine_3pJa7VOx);
  numBytes += sLine_init(&sLine_KkIWiYKr);
  numBytes += sLine_init(&sLine_N7LOpir6);
  numBytes += sBiquad_init(&sBiquad_s_GaBq8qZy);
  numBytes += sLine_init(&sLine_tIpIn8HP);
  numBytes += sLine_init(&sLine_ow1augDd);
  numBytes += sLine_init(&sLine_dHcqEDuZ);
  numBytes += sLine_init(&sLine_TiXqE19e);
  numBytes += sLine_init(&sLine_PKPN8mEC);
  numBytes += sBiquad_init(&sBiquad_s_LwupsrmM);
  numBytes += sLine_init(&sLine_Ywq6AxvP);
  numBytes += sLine_init(&sLine_AVUbRAag);
  numBytes += sLine_init(&sLine_zdLfJnDu);
  numBytes += sLine_init(&sLine_1wocVNbL);
  numBytes += sLine_init(&sLine_3IayYz1c);
  numBytes += sBiquad_init(&sBiquad_s_r15jLAC4);
  numBytes += sLine_init(&sLine_yHCuHwZp);
  numBytes += sLine_init(&sLine_MQYyz720);
  numBytes += sLine_init(&sLine_uqtqW54G);
  numBytes += sLine_init(&sLine_8ujU2d8E);
  numBytes += sBiquad_init(&sBiquad_s_QpeDGUDZ);
  numBytes += sLine_init(&sLine_PNKDZY61);
  numBytes += sLine_init(&sLine_3cH4PAfL);
  numBytes += sLine_init(&sLine_QgPUefYU);
  numBytes += sLine_init(&sLine_JeYDHWuI);
  numBytes += sLine_init(&sLine_EX2dHiPm);
  numBytes += sBiquad_init(&sBiquad_s_27NU34l5);
  numBytes += sLine_init(&sLine_if2KQ2Kj);
  numBytes += sPhasor_k_init(&sPhasor_LDEIBBDI, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_Er9mFktG);
  numBytes += sRPole_init(&sRPole_k8x01EiG);
  numBytes += sRPole_init(&sRPole_3CRoBBbM);
  numBytes += sTabhead_init(&sTabhead_5M8UKNCx, &hTable_13qWpMwN);
  numBytes += sTabread_init(&sTabread_TTE6AIQX, &hTable_13qWpMwN, false);
  numBytes += sTabread_init(&sTabread_TcUNA81x, &hTable_13qWpMwN, false);
  numBytes += sLine_init(&sLine_kiiq6Xfo);
  numBytes += sTabhead_init(&sTabhead_uNZDkW1U, &hTable_EoJSgAHR);
  numBytes += sTabread_init(&sTabread_C1dScRyq, &hTable_EoJSgAHR, false);
  numBytes += sTabread_init(&sTabread_oQPWYu2s, &hTable_EoJSgAHR, false);
  numBytes += sLine_init(&sLine_9DPu3hse);
  numBytes += sTabwrite_init(&sTabwrite_Qdm35qSU, &hTable_EoJSgAHR);
  numBytes += sTabwrite_init(&sTabwrite_FdRymPeH, &hTable_13qWpMwN);
  numBytes += sLine_init(&sLine_DcN9K9V8);
  numBytes += sPhasor_k_init(&sPhasor_pNHHKuqg, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_sZXWE02r);
  numBytes += sRPole_init(&sRPole_ar0tyJnb);
  numBytes += sRPole_init(&sRPole_2HzMCdqe);
  numBytes += sTabhead_init(&sTabhead_bMlQmt8u, &hTable_njrfB8je);
  numBytes += sTabread_init(&sTabread_laRjgD5y, &hTable_njrfB8je, false);
  numBytes += sTabread_init(&sTabread_GdUG6gMm, &hTable_njrfB8je, false);
  numBytes += sLine_init(&sLine_HePiWqR1);
  numBytes += sTabhead_init(&sTabhead_oSyBAf7h, &hTable_tY2Tok9D);
  numBytes += sTabread_init(&sTabread_0jv1OnUW, &hTable_tY2Tok9D, false);
  numBytes += sTabread_init(&sTabread_0ekjSuyP, &hTable_tY2Tok9D, false);
  numBytes += sLine_init(&sLine_sQJBthcd);
  numBytes += sTabwrite_init(&sTabwrite_BQqfwjtC, &hTable_tY2Tok9D);
  numBytes += sTabwrite_init(&sTabwrite_pVuivMdQ, &hTable_njrfB8je);
  numBytes += sLine_init(&sLine_HUT2TAdW);
  numBytes += sPhasor_k_init(&sPhasor_OO5lEkFL, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_NiMhLQGl);
  numBytes += sRPole_init(&sRPole_WHUUoE7L);
  numBytes += sRPole_init(&sRPole_vM1tfxS3);
  numBytes += sTabhead_init(&sTabhead_ITkCfxnG, &hTable_qQFl8ajt);
  numBytes += sTabread_init(&sTabread_M1CxJwDS, &hTable_qQFl8ajt, false);
  numBytes += sTabread_init(&sTabread_0knoswvn, &hTable_qQFl8ajt, false);
  numBytes += sLine_init(&sLine_hoYmEUzQ);
  numBytes += sTabhead_init(&sTabhead_xxOWQeQz, &hTable_OHQ34Isc);
  numBytes += sTabread_init(&sTabread_7fUZjlQh, &hTable_OHQ34Isc, false);
  numBytes += sTabread_init(&sTabread_WVnrwdYv, &hTable_OHQ34Isc, false);
  numBytes += sLine_init(&sLine_3KG0iEj1);
  numBytes += sTabwrite_init(&sTabwrite_S52q2reb, &hTable_OHQ34Isc);
  numBytes += sTabwrite_init(&sTabwrite_3olcHRWz, &hTable_qQFl8ajt);
  numBytes += cVar_init_f(&cVar_seY2LPY7, 0.0f);
  numBytes += cVar_init_f(&cVar_45zUKSd6, 0.0f);
  numBytes += cVar_init_f(&cVar_MJo4YCVh, 0.0f);
  numBytes += cVar_init_f(&cVar_ILXSFPhB, 0.0f);
  numBytes += cSlice_init(&cSlice_8AaYC36Z, 1, -1);
  numBytes += cVar_init_f(&cVar_R2XDudXA, 1337.0f);
  numBytes += cVar_init_f(&cVar_JKBYhmm8, 0.0f);
  numBytes += cIf_init(&cIf_zcdjqJ7q, false);
  numBytes += cIf_init(&cIf_w8qhLl36, false);
  numBytes += cBinop_init(&cBinop_o3fXbV0d, 0.0f); // __pow
  numBytes += cIf_init(&cIf_CmOiZjtv, false);
  numBytes += cBinop_init(&cBinop_hKTyk7Jg, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_fMzNzkGB, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_3YVyQwx3, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_yZheHYAU, 0.0f);
  numBytes += cIf_init(&cIf_LzgzVc5d, false);
  numBytes += cIf_init(&cIf_oMH5mImq, false);
  numBytes += cBinop_init(&cBinop_B726IHKj, 0.0f); // __pow
  numBytes += cIf_init(&cIf_rBLfwXar, false);
  numBytes += cBinop_init(&cBinop_gcv3mQSV, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_CtF04aHS, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_UuXmyYra, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_MRaM30jw, 0.0f);
  numBytes += cIf_init(&cIf_uS1e6bCk, false);
  numBytes += cIf_init(&cIf_V0K4wahe, false);
  numBytes += cBinop_init(&cBinop_rPnG7wWa, 0.0f); // __pow
  numBytes += cIf_init(&cIf_86C60jaO, false);
  numBytes += cBinop_init(&cBinop_ShWaHNG3, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_onYLx8FQ, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_Jo6U2KZD, -15.0f); // __eq
  numBytes += cIf_init(&cIf_ItfYA8by, false);
  numBytes += cSlice_init(&cSlice_3DKaADOS, 1, -1);
  numBytes += cVar_init_f(&cVar_b4Neq8TV, 0.0f);
  numBytes += cSlice_init(&cSlice_Oa4z0yLc, 1, -1);
  numBytes += cVar_init_f(&cVar_KRLisLj8, 0.0f);
  numBytes += cSlice_init(&cSlice_U3Ncw80S, 1, -1);
  numBytes += cVar_init_f(&cVar_0iYcrJUr, 0.0f);
  numBytes += cSlice_init(&cSlice_EpnKWMvZ, 1, -1);
  numBytes += cVar_init_f(&cVar_yRQkWDAW, 0.313f);
  numBytes += cBinop_init(&cBinop_dHzPMu9o, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_dGZn0z5T, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_1eHkFOfO, 0.0f);
  numBytes += cVar_init_f(&cVar_85clalx0, 1337.0f);
  numBytes += cVar_init_f(&cVar_0Xb884B2, 0.3f);
  numBytes += cBinop_init(&cBinop_ZkYgtK0K, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zsHiVE6V, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_w2Ear1Xd, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_oGq9PHS0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QGSK5m8L, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9Y91ynzq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lfvg4HpD, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_WnSmg5Pn, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_2qXOByvj, 0.0f);
  numBytes += cVar_init_f(&cVar_7hJyqIRa, 1337.0f);
  numBytes += cVar_init_f(&cVar_4ULPxa4G, 0.313f);
  numBytes += cBinop_init(&cBinop_lASL9QkA, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_YCtuiaut, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_nulAHebh, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_eATlU9d7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ZYNdW2LA, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_07sTpVm7, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_QKP9DHkh, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_PmospOX5, 0.0f);
  numBytes += cVar_init_f(&cVar_t1G2JKG0, 1037.0f);
  numBytes += cVar_init_f(&cVar_ekx1ZD06, 0.4f);
  numBytes += cBinop_init(&cBinop_HRIF1mpM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_LW8cQhKB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1qLkP5hC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zbV5CKEN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KncS2Zeu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1gE7u8rn, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_bb3zrCiZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_KWNJJsPO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iGARSpqS, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_xpVYQLXk, 1, -1);
  numBytes += cVar_init_f(&cVar_T29lSpyH, 1337.0f);
  numBytes += cVar_init_f(&cVar_00slYsaz, 0.0f);
  numBytes += cIf_init(&cIf_qKDyVsKA, false);
  numBytes += cIf_init(&cIf_96UeIy62, false);
  numBytes += cBinop_init(&cBinop_n4DMvizB, 0.0f); // __pow
  numBytes += cIf_init(&cIf_0s63YwLc, false);
  numBytes += cBinop_init(&cBinop_Wdrhlh4q, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_bphjMkLM, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_jJwXIGYY, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_ACgbwoi4, 0.0f);
  numBytes += cIf_init(&cIf_7ur46vuH, false);
  numBytes += cIf_init(&cIf_fwifERYr, false);
  numBytes += cBinop_init(&cBinop_HmquPZYx, 0.0f); // __pow
  numBytes += cIf_init(&cIf_xZEeHCfe, false);
  numBytes += cBinop_init(&cBinop_sukBkoVE, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_KV3yGmMp, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_pf6BXP0z, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_if1PZSMR, 0.0f);
  numBytes += cIf_init(&cIf_JbNuB8C7, false);
  numBytes += cIf_init(&cIf_AUHUhe2o, false);
  numBytes += cBinop_init(&cBinop_FSybD9MD, 0.0f); // __pow
  numBytes += cIf_init(&cIf_PPt6JkYv, false);
  numBytes += cBinop_init(&cBinop_PENM6l6Z, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_upkjiwpw, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_7G7gT3oJ, -15.0f); // __eq
  numBytes += cIf_init(&cIf_EJ0ypq09, false);
  numBytes += cSlice_init(&cSlice_fZIG3nw5, 1, -1);
  numBytes += cVar_init_f(&cVar_mHH8JuHL, 0.0f);
  numBytes += cSlice_init(&cSlice_RQF2Ip6s, 1, -1);
  numBytes += cVar_init_f(&cVar_JrDMldfC, 0.0f);
  numBytes += cSlice_init(&cSlice_4mUInMmZ, 1, -1);
  numBytes += cVar_init_f(&cVar_5ThPzORN, 0.0f);
  numBytes += cSlice_init(&cSlice_uZKuhP2f, 1, -1);
  numBytes += cVar_init_f(&cVar_ln71GCMl, 0.313f);
  numBytes += cBinop_init(&cBinop_5EXqRa5y, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_IlzXAO9a, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_Jd8o1QHa, 0.0f);
  numBytes += cVar_init_f(&cVar_RhIBlrJS, 1337.0f);
  numBytes += cVar_init_f(&cVar_copmYxf4, 0.3f);
  numBytes += cBinop_init(&cBinop_XVmWVm6C, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ldNyTlnY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6qK4O2Kc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Wii2YnOy, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xwakBIwY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dlemU0pV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5Rxs4bnI, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_gcUCwyKZ, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_euOTvfzU, 0.0f);
  numBytes += cVar_init_f(&cVar_tUJulrVF, 1337.0f);
  numBytes += cVar_init_f(&cVar_5tgF5oNv, 0.313f);
  numBytes += cBinop_init(&cBinop_tV7Ee1Vt, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_a5blsDCX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_oSvEIovD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bbN4vb2d, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Oh0efpQ1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vFq7Gesm, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_NkNE0wm4, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_qD5k4uol, 0.0f);
  numBytes += cVar_init_f(&cVar_UqS0h04a, 1037.0f);
  numBytes += cVar_init_f(&cVar_3G0j3Pn1, 0.4f);
  numBytes += cBinop_init(&cBinop_unwdamnY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_B61IJChv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_YNgWADib, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jXrC5xj5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_YYxAnRC1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7VmSyPW8, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_53TgzYsS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dgz8F2dt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_niiSCNdH, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_6922t5lB, 5705.6f);
  numBytes += cVar_init_f(&cVar_iJIGqCQu, 313.3f);
  numBytes += cBinop_init(&cBinop_1x5hJHaB, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_XCKaxUVY, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_QcMOR4u8, 0.0f); // __div
  numBytes += cVar_init_f(&cVar_JnMV7MZa, 0.0f);
  numBytes += cVar_init_f(&cVar_9JJSau5p, 0.0f);
  numBytes += cVar_init_f(&cVar_1utfuWq1, 0.0f);
  numBytes += cVar_init_f(&cVar_gVFrC7dK, 0.0f);
  numBytes += cVar_init_f(&cVar_bnh68LGW, 0.0f);
  numBytes += cVar_init_f(&cVar_HLZRSZri, 0.0f);
  numBytes += cVar_init_f(&cVar_AMlioFPJ, 0.0f);
  numBytes += cVar_init_f(&cVar_tKWt2ajs, 0.0f);
  numBytes += cVar_init_f(&cVar_Hu8EM7Hg, 0.0f);
  numBytes += cVar_init_f(&cVar_Oz0vNkfe, 0.0f);
  numBytes += cVar_init_f(&cVar_clezGTKR, 0.0f);
  numBytes += cVar_init_f(&cVar_smYM9KJH, 0.0f);
  numBytes += cVar_init_s(&cVar_dfMh03Wz, "del-1348-flanger-l");
  numBytes += sVarf_init(&sVarf_lqdZnbMS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mDjiCuNu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3h7z1rqd, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_Td7Gkmr7, "del-1348-flanger-r");
  numBytes += sVarf_init(&sVarf_4xjwMElb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MdRe3iAQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_msnUTrtq, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_57pXT9o4, 0.0f);
  numBytes += cDelay_init(this, &cDelay_6LxN2jTB, 0.0f);
  numBytes += hTable_init(&hTable_EoJSgAHR, 256);
  numBytes += cDelay_init(this, &cDelay_FLHIVKp0, 0.0f);
  numBytes += cDelay_init(this, &cDelay_f3OY4ixW, 0.0f);
  numBytes += hTable_init(&hTable_13qWpMwN, 256);
  numBytes += cVar_init_f(&cVar_XFYEVGHw, 14.0f);
  numBytes += cBinop_init(&cBinop_Twl2GDLo, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_B1eu3pPg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Ahi3MdNM, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_eZz5MX1Z, 14.0f);
  numBytes += cBinop_init(&cBinop_lYnjfUgc, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_cBIrdxD2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fN3kf1uO, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_2zl2cljS, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_guT9GLAH, 1, -1);
  numBytes += cVar_init_f(&cVar_ZDVTHBF0, 0.2f);
  numBytes += cSlice_init(&cSlice_10XFUHWF, 1, -1);
  numBytes += cVar_init_f(&cVar_6cn2f5Rv, 0.0f);
  numBytes += cSlice_init(&cSlice_CJo8KBxt, 1, -1);
  numBytes += cVar_init_f(&cVar_BYGLEnC6, 2.0f);
  numBytes += cSlice_init(&cSlice_ajOBMZTX, 1, -1);
  numBytes += cVar_init_f(&cVar_xVwvHsDs, 0.5f);
  numBytes += cVar_init_s(&cVar_SXFFteIL, "del-1397-flanger-l");
  numBytes += sVarf_init(&sVarf_BCV3gzcv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SuvAPki8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Slkl1VYZ, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_8KdTyqe7, "del-1397-flanger-r");
  numBytes += sVarf_init(&sVarf_Nik7EkMI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0jsZbEe2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vrUgYlqu, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_9A6P4h7h, 0.0f);
  numBytes += cDelay_init(this, &cDelay_bw9fqP2M, 0.0f);
  numBytes += hTable_init(&hTable_tY2Tok9D, 256);
  numBytes += cDelay_init(this, &cDelay_xXtvt9Q8, 0.0f);
  numBytes += cDelay_init(this, &cDelay_L8sK6si1, 0.0f);
  numBytes += hTable_init(&hTable_njrfB8je, 256);
  numBytes += cVar_init_f(&cVar_37gBMdge, 14.0f);
  numBytes += cBinop_init(&cBinop_YeP73Pve, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_AR1GpwfO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jUByUiC0, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_7AfRTEIu, 14.0f);
  numBytes += cBinop_init(&cBinop_iSUessSP, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_JRcDXLjU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_G8cnrmSN, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_fyWmDjA2, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_QIwSA4Qk, 1, -1);
  numBytes += cVar_init_f(&cVar_mzs9ng0B, 0.2f);
  numBytes += cSlice_init(&cSlice_fd3nvtnM, 1, -1);
  numBytes += cVar_init_f(&cVar_ZHWMDjRh, 0.0f);
  numBytes += cSlice_init(&cSlice_MtXw1Ywv, 1, -1);
  numBytes += cVar_init_f(&cVar_v4wh0Ziv, 2.0f);
  numBytes += cSlice_init(&cSlice_4fAUxgPP, 1, -1);
  numBytes += cVar_init_f(&cVar_bNABAef4, 0.5f);
  numBytes += cVar_init_s(&cVar_IA5A2U44, "del-1446-flanger-l");
  numBytes += sVarf_init(&sVarf_R6VDCSVA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Phqr5L9W, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4HQPB4a7, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_Y3q7XLHk, "del-1446-flanger-r");
  numBytes += sVarf_init(&sVarf_S1uJUz2k, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_IDZopqVd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_08hnKi59, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_KSqbWdfn, 0.0f);
  numBytes += cDelay_init(this, &cDelay_4bC3Ivro, 0.0f);
  numBytes += hTable_init(&hTable_OHQ34Isc, 256);
  numBytes += cDelay_init(this, &cDelay_TSnCbGh1, 0.0f);
  numBytes += cDelay_init(this, &cDelay_MAPajAOV, 0.0f);
  numBytes += hTable_init(&hTable_qQFl8ajt, 256);
  numBytes += cVar_init_f(&cVar_CYZ8r3B0, 14.0f);
  numBytes += cBinop_init(&cBinop_vjo8DCJZ, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_5NVBgRkf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xb6P6MFO, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_wkJf00bk, 14.0f);
  numBytes += cBinop_init(&cBinop_o5xgmV6u, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_53ckMoCZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Hk5mAGKl, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_xIabs3lK, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_Y7ZKB6JC, 1, -1);
  numBytes += cVar_init_f(&cVar_lTPBWCdW, 0.2f);
  numBytes += cSlice_init(&cSlice_GEKu7BAG, 1, -1);
  numBytes += cVar_init_f(&cVar_tX5uB8t6, 0.0f);
  numBytes += cSlice_init(&cSlice_9WEf8QgO, 1, -1);
  numBytes += cVar_init_f(&cVar_nzrziBGS, 2.0f);
  numBytes += cSlice_init(&cSlice_DadM4Hhq, 1, -1);
  numBytes += cVar_init_f(&cVar_HJglZzAv, 0.5f);
  numBytes += sVarf_init(&sVarf_tmHmWHLY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jb5j9Dul, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gxhma5Va, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_zq6ZOvAM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3kscW9n9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_P80tBW52, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_FL3NGR::~Heavy_WSTD_FL3NGR() {
  hTable_free(&hTable_EoJSgAHR);
  hTable_free(&hTable_13qWpMwN);
  hTable_free(&hTable_tY2Tok9D);
  hTable_free(&hTable_njrfB8je);
  hTable_free(&hTable_OHQ34Isc);
  hTable_free(&hTable_qQFl8ajt);
}

HvTable *Heavy_WSTD_FL3NGR::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x7E84AE7C: return &hTable_EoJSgAHR; // del-1348-flanger-r
    case 0x8BC7EF65: return &hTable_13qWpMwN; // del-1348-flanger-l
    case 0x67C454D4: return &hTable_tY2Tok9D; // del-1397-flanger-r
    case 0x578173CB: return &hTable_njrfB8je; // del-1397-flanger-l
    case 0xB5F31EFF: return &hTable_OHQ34Isc; // del-1446-flanger-r
    case 0xFB92DE56: return &hTable_qQFl8ajt; // del-1446-flanger-l
    default: return nullptr;
  }
}

void Heavy_WSTD_FL3NGR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_R7nSVpl3_sendMessage);
      break;
    }
    case 0xACE44B9C: { // High_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FNqR7SPw_sendMessage);
      break;
    }
    case 0xA66E154B: { // High_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wmkKMNyr_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_x0yQcVn7_sendMessage);
      break;
    }
    case 0x49068FB0: { // High_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jfYPXaIQ_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_x8n1LDRa_sendMessage);
      break;
    }
    case 0xDDAB7A0: { // Low_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TBhNLEF2_sendMessage);
      break;
    }
    case 0xF8FE7D54: { // Low_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JER2KDT1_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gYfE6U9B_sendMessage);
      break;
    }
    case 0x768962E9: { // Low_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jouQAKBA_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KdWEb5Q9_sendMessage);
      break;
    }
    case 0x9B44FA2D: { // Mid_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ona5TNl7_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0xICrInX_sendMessage);
      break;
    }
    case 0x30AE5EFB: { // Mid_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_W5PUPxVe_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2EDG4QjG_sendMessage);
      break;
    }
    case 0x78CC8F6D: { // Mid_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6zFVunh5_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6AVETlxc_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yOgjppCU_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TJeSYfYU_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eV2OhUJs_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZUyoLbE2_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bzPHzthc_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_obf9exG9_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KuldcLmh_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CW7zqlyo_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mpIClhsL_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AdURBmyo_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xGsLeFuP_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SEnG2PZe_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rqJJ1gSt_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uO5NjQaD_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_02PNQ4jX_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NfbA0M8R_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VoUCMCif_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DsuyVb0v_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ap026MqY_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VN1SwWov_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7neyIP7L_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Nt4zBirt_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sDdzILNU_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2yJDQU8R_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DWRBdvb8_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Tr2UmoBy_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tPAgd0Eu_sendMessage);
      break;
    }
    case 0xB9261D01: { // 1348-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EShcuGGK_sendMessage);
      break;
    }
    case 0x7B4AB7DC: { // 1348-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WDo5H596_sendMessage);
      break;
    }
    case 0xC21D5730: { // 1348-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hBiF29Ml_sendMessage);
      break;
    }
    case 0x73E3A43F: { // 1348-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CwzzB1GA_sendMessage);
      break;
    }
    case 0x8020E246: { // 1397-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tTyhOArW_sendMessage);
      break;
    }
    case 0xDE6EF86C: { // 1397-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Xq6jlpjh_sendMessage);
      break;
    }
    case 0x4C9CDCA8: { // 1397-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_d2pC8NtJ_sendMessage);
      break;
    }
    case 0xB69DF8D2: { // 1397-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pYfDZZVn_sendMessage);
      break;
    }
    case 0x2ABB5D7C: { // 1446-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_S24bjmur_sendMessage);
      break;
    }
    case 0xE9A86FE0: { // 1446-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZpU0P97T_sendMessage);
      break;
    }
    case 0xC66A3021: { // 1446-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_r2rEPl15_sendMessage);
      break;
    }
    case 0x64835C2: { // 1446-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ks4C5tR6_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Mujgqiqa_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_FL3NGR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Feedback";
        info->hash = 0xACE44B9C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "High_Intensity";
        info->hash = 0xA66E154B;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 3: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 4: {
        info->name = "High_Speed";
        info->hash = 0x49068FB0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 5: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "Low_Feedback";
        info->hash = 0xDDAB7A0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 7: {
        info->name = "Low_Intensity";
        info->hash = 0xF8FE7D54;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 8: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 9: {
        info->name = "Low_Speed";
        info->hash = 0x768962E9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 10: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "Mid_Feedback";
        info->hash = 0x9B44FA2D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 13: {
        info->name = "Mid_Intensity";
        info->hash = 0x30AE5EFB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 14: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 15: {
        info->name = "Mid_Speed";
        info->hash = 0x78CC8F6D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 16;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_FL3NGR::cVar_seY2LPY7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q3elWbyb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_45zUKSd6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5iRqFO9u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_MJo4YCVh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_201oEMIy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_ILXSFPhB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Z5yQFFE5_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_csyhnKG3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_18hxzrYl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9o8RVllB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_LHOBkcVF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_8AaYC36Z, 0, m, &cSlice_8AaYC36Z_sendMessage);
      break;
    }
    default: {
      cSwitchcase_KWkeM30D_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_8AaYC36Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_LOxt93Bo_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_LOxt93Bo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_R2XDudXA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LOxt93Bo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_LOxt93Bo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_TJeSYfYU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_JKBYhmm8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_lbNQcc2A_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_zcdjqJ7q, 0, m, &cIf_zcdjqJ7q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_zcdjqJ7q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_j5JpWMAO_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_w8qhLl36_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_psZAu8rD_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_GV0WMfMn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_9EvragET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_o3fXbV0d, HV_BINOP_POW, 0, m, &cBinop_o3fXbV0d_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_o3fXbV0d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CmOiZjtv, 0, m, &cIf_CmOiZjtv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cY7F85IX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_pLGuIZYK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_nK7Iv9tR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_297Do6tN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_KZyvDhCA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_w8qhLl36, 0, m, &cIf_w8qhLl36_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_297Do6tN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_w8qhLl36, 1, m, &cIf_w8qhLl36_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GV0WMfMn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_cY7F85IX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_psZAu8rD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_CmOiZjtv, 0, m, &cIf_CmOiZjtv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pLGuIZYK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_o3fXbV0d, HV_BINOP_POW, 1, m, &cBinop_o3fXbV0d_sendMessage);
  cMsg_9EvragET_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_CmOiZjtv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_bb3zrCiZ, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_lbNQcc2A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zcdjqJ7q, 1, m, &cIf_zcdjqJ7q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_j5JpWMAO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fMzNzkGB, HV_BINOP_GREATER_THAN, 1, m, &cBinop_fMzNzkGB_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3YVyQwx3, HV_BINOP_EQ, 1, m, &cBinop_3YVyQwx3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_QPPcSxTV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_hKTyk7Jg, HV_BINOP_ADD, 0, m, &cBinop_hKTyk7Jg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hKTyk7Jg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nK7Iv9tR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KZyvDhCA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fMzNzkGB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CmOiZjtv, 1, m, &cIf_CmOiZjtv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3YVyQwx3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4530DbQH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_4530DbQH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_bb3zrCiZ, m);
}

void Heavy_WSTD_FL3NGR::cCast_Qq2YZgHS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QPPcSxTV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_sIeeAK63_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JKBYhmm8, 0, m, &cVar_JKBYhmm8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_9tN1GdOw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hKTyk7Jg, HV_BINOP_ADD, 1, m, &cBinop_hKTyk7Jg_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_fMzNzkGB, HV_BINOP_GREATER_THAN, 0, m, &cBinop_fMzNzkGB_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3YVyQwx3, HV_BINOP_EQ, 0, m, &cBinop_3YVyQwx3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_yZheHYAU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_wdreOXAZ_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_LzgzVc5d, 0, m, &cIf_LzgzVc5d_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_LzgzVc5d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_L1emqd9V_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_oMH5mImq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_YHy0Wy0H_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_OJXIadx5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_Pd0K6Wk6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_B726IHKj, HV_BINOP_POW, 0, m, &cBinop_B726IHKj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_B726IHKj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rBLfwXar, 0, m, &cIf_rBLfwXar_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_llLEbnFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_OEYR3GH9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_5u7Ksm28_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oMH5mImq, 0, m, &cIf_oMH5mImq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_BtT6DccB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_5WBcxYFL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5WBcxYFL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oMH5mImq, 1, m, &cIf_oMH5mImq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OJXIadx5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_llLEbnFf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_YHy0Wy0H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_rBLfwXar, 0, m, &cIf_rBLfwXar_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OEYR3GH9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B726IHKj, HV_BINOP_POW, 1, m, &cBinop_B726IHKj_sendMessage);
  cMsg_Pd0K6Wk6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_rBLfwXar_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ZGFUg7b7_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bX4CdJGR_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_OJ9wNvHw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_wdreOXAZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LzgzVc5d, 1, m, &cIf_LzgzVc5d_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_L1emqd9V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CtF04aHS, HV_BINOP_GREATER_THAN, 1, m, &cBinop_CtF04aHS_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UuXmyYra, HV_BINOP_EQ, 1, m, &cBinop_UuXmyYra_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_yF7WBiWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gcv3mQSV, HV_BINOP_ADD, 0, m, &cBinop_gcv3mQSV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gcv3mQSV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BtT6DccB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5u7Ksm28_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CtF04aHS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rBLfwXar, 1, m, &cIf_rBLfwXar_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UuXmyYra_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GZPgPZob_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_GZPgPZob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ZGFUg7b7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bX4CdJGR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_OJ9wNvHw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_gBTLOuNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yZheHYAU, 0, m, &cVar_yZheHYAU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_we8MrJOK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yF7WBiWS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_IQcl9pPs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gcv3mQSV, HV_BINOP_ADD, 1, m, &cBinop_gcv3mQSV_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CtF04aHS, HV_BINOP_GREATER_THAN, 0, m, &cBinop_CtF04aHS_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UuXmyYra, HV_BINOP_EQ, 0, m, &cBinop_UuXmyYra_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_MRaM30jw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_YiKSJHI5_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_uS1e6bCk, 0, m, &cIf_uS1e6bCk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_uS1e6bCk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_6I9O20KX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_V0K4wahe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_OZpsvEeN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_tCOF6mSL_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_R9mMmuWi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rPnG7wWa, HV_BINOP_POW, 0, m, &cBinop_rPnG7wWa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rPnG7wWa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_86C60jaO, 0, m, &cIf_86C60jaO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QirJQ4gA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_cv4kIJmm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_IrRLRIKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_V0K4wahe, 0, m, &cIf_V0K4wahe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_YYVqXWCF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_TO2it7xA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TO2it7xA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_V0K4wahe, 1, m, &cIf_V0K4wahe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tCOF6mSL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_QirJQ4gA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_OZpsvEeN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_86C60jaO, 0, m, &cIf_86C60jaO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cv4kIJmm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rPnG7wWa, HV_BINOP_POW, 1, m, &cBinop_rPnG7wWa_sendMessage);
  cMsg_R9mMmuWi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_86C60jaO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_iGARSpqS, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_YiKSJHI5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uS1e6bCk, 1, m, &cIf_uS1e6bCk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6I9O20KX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_onYLx8FQ, HV_BINOP_GREATER_THAN, 1, m, &cBinop_onYLx8FQ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jo6U2KZD, HV_BINOP_EQ, 1, m, &cBinop_Jo6U2KZD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_alIzAaoy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ShWaHNG3, HV_BINOP_ADD, 0, m, &cBinop_ShWaHNG3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ShWaHNG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YYVqXWCF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IrRLRIKB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_onYLx8FQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_86C60jaO, 1, m, &cIf_86C60jaO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Jo6U2KZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0lS1bEN5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_0lS1bEN5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_iGARSpqS, m);
}

void Heavy_WSTD_FL3NGR::cCast_rIQ342P5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_alIzAaoy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_nwS977ax_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ShWaHNG3, HV_BINOP_ADD, 1, m, &cBinop_ShWaHNG3_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_onYLx8FQ, HV_BINOP_GREATER_THAN, 0, m, &cBinop_onYLx8FQ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jo6U2KZD, HV_BINOP_EQ, 0, m, &cBinop_Jo6U2KZD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_xnoRpFRj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MRaM30jw, 0, m, &cVar_MRaM30jw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_ItfYA8by_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_KWNJJsPO, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cSwitchcase_SSnEOiXN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3DKaADOS, 0, m, &cSlice_3DKaADOS_sendMessage);
      break;
    }
    default: {
      cSwitchcase_6Y0holKE_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_3DKaADOS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Z1w9U9hJ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Z1w9U9hJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_b4Neq8TV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Z1w9U9hJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_Z1w9U9hJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6AVETlxc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_6Y0holKE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Oa4z0yLc, 0, m, &cSlice_Oa4z0yLc_sendMessage);
      break;
    }
    default: {
      cSwitchcase_LHOBkcVF_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_Oa4z0yLc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_lV8pFMbX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_lV8pFMbX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_KRLisLj8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lV8pFMbX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_lV8pFMbX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZUyoLbE2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_KWkeM30D_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_U3Ncw80S, 0, m, &cSlice_U3Ncw80S_sendMessage);
      break;
    }
    default: {
      cSwitchcase_jF0wkRPD_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_U3Ncw80S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_WIEuehBW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_WIEuehBW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_0iYcrJUr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WIEuehBW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_WIEuehBW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yOgjppCU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_jF0wkRPD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_EpnKWMvZ, 0, m, &cSlice_EpnKWMvZ_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_EpnKWMvZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GxPrbKE0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GxPrbKE0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_yRQkWDAW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GxPrbKE0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_GxPrbKE0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eV2OhUJs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_XpTe0Ji7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jurx6EIB, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_EHK6VT4K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EUmf9ANc, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_FHQdKvWg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RuzPx7Z9, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_6P8sxdGo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FrngpOrg, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_27eGmaQj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SVa9Anlu, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_wDyKmpOq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Z1YrIBZT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_Z1YrIBZT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dHzPMu9o, HV_BINOP_DIVIDE, 1, m, &cBinop_dHzPMu9o_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KvKnpQFP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_QwDNACjZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_c9d1N3os_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_EQCCezsx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_QwDNACjZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_c9d1N3os_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dHzPMu9o, HV_BINOP_DIVIDE, 0, m, &cBinop_dHzPMu9o_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_KvKnpQFP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EQCCezsx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_dHzPMu9o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dGZn0z5T, HV_BINOP_MULTIPLY, 1, m, &cBinop_dGZn0z5T_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dGZn0z5T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8CQ5AoTr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IrkNvGUw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_bfCedSYQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6JkAM7A3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_QsQR7pxS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xVz5KvTr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ofufUVFn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_0FXHc5fN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0FXHc5fN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dGZn0z5T, HV_BINOP_MULTIPLY, 0, m, &cBinop_dGZn0z5T_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bieqr4nf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_ITIkMeGb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ITIkMeGb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_glc3JEhG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Icp498mt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1eHkFOfO, 1, m, &cVar_1eHkFOfO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_1eHkFOfO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e11mCAra_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_DTIWmMxp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zsHiVE6V, HV_BINOP_MULTIPLY, 1, m, &cBinop_zsHiVE6V_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bqQZBIRp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_DTIWmMxp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0ymE4Cwe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_u11y5Ur3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_u11y5Ur3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w2Ear1Xd, HV_BINOP_MULTIPLY, 1, m, &cBinop_w2Ear1Xd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mG8FaHG7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oGq9PHS0, HV_BINOP_MULTIPLY, 1, m, &cBinop_oGq9PHS0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GBINGNEd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_mG8FaHG7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CqSPT8Qm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QGSK5m8L, HV_BINOP_MULTIPLY, 1, m, &cBinop_QGSK5m8L_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_4oeODpYP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_99iCyqlC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_99iCyqlC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9Y91ynzq, HV_BINOP_MULTIPLY, 1, m, &cBinop_9Y91ynzq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_85clalx0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PVSH1Gk0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_ofufUVFn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_y9stdtev_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_0Xb884B2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_bieqr4nf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_IrkNvGUw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_QsQR7pxS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_8CQ5AoTr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_bfCedSYQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_6JkAM7A3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KuldcLmh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_xVz5KvTr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_obf9exG9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_htqZYd5H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bzPHzthc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_glc3JEhG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_VkqWJmB7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VkqWJmB7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZkYgtK0K, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZkYgtK0K_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZkYgtK0K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_nDL2taaM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nDL2taaM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_htqZYd5H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_e11mCAra_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_gmfPyzUq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gmfPyzUq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rWUaE7eH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aov5RyHQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nGW40xFH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_arWFkfKL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ofliAZbY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eIRZUZQI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zsHiVE6V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XpTe0Ji7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_w2Ear1Xd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EHK6VT4K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_oGq9PHS0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FHQdKvWg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_QGSK5m8L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6P8sxdGo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_9Y91ynzq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_27eGmaQj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_RLEgIvbd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_85clalx0, 0, m, &cVar_85clalx0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_vf0ejvRP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0Xb884B2, 1, m, &cVar_0Xb884B2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_aov5RyHQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9Y91ynzq, HV_BINOP_MULTIPLY, 0, m, &cBinop_9Y91ynzq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_eIRZUZQI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zsHiVE6V, HV_BINOP_MULTIPLY, 0, m, &cBinop_zsHiVE6V_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ofliAZbY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w2Ear1Xd, HV_BINOP_MULTIPLY, 0, m, &cBinop_w2Ear1Xd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_rWUaE7eH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_arWFkfKL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oGq9PHS0, HV_BINOP_MULTIPLY, 0, m, &cBinop_oGq9PHS0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_nGW40xFH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QGSK5m8L, HV_BINOP_MULTIPLY, 0, m, &cBinop_QGSK5m8L_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_PVSH1Gk0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0Xb884B2, 0, m, &cVar_0Xb884B2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_y9stdtev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1eHkFOfO, 0, m, &cVar_1eHkFOfO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_xhUzTUGE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_41u3hJH9, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_qDHqT4d2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3pJa7VOx, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_PrspZkhR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KkIWiYKr, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_YCvEqNzo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_N7LOpir6, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_uFDV7Pmi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_bZzzIAZq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_bZzzIAZq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lfvg4HpD, HV_BINOP_DIVIDE, 1, m, &cBinop_lfvg4HpD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wFdq2zzm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_Mvs96N9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_acKiasMj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_tuTO3Mxm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Mvs96N9U_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_acKiasMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lfvg4HpD, HV_BINOP_DIVIDE, 0, m, &cBinop_lfvg4HpD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_wFdq2zzm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tuTO3Mxm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_lfvg4HpD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WnSmg5Pn, HV_BINOP_MULTIPLY, 1, m, &cBinop_WnSmg5Pn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WnSmg5Pn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zy0zSOtn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ePFR2Nvx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_YUvSB0SS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Dakk2SBY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_3IYGs99r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_TXNbtBo3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_CiWrZroA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_8DFJCe5W_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8DFJCe5W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WnSmg5Pn, HV_BINOP_MULTIPLY, 0, m, &cBinop_WnSmg5Pn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TkpmPBSN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_kAstTO9b_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kAstTO9b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lvILrysQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_UZcRbIV9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nulAHebh, HV_BINOP_MULTIPLY, 1, m, &cBinop_nulAHebh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ULgr3cud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2qXOByvj, 1, m, &cVar_2qXOByvj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bklc5W2D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eATlU9d7, HV_BINOP_MULTIPLY, 1, m, &cBinop_eATlU9d7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_hZqkM545_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_5C3QXgLk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5C3QXgLk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZYNdW2LA, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZYNdW2LA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_2qXOByvj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3tA8x96i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_7hJyqIRa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h7dHeq7n_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_CiWrZroA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DyEo7H1S_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_4ULPxa4G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_TkpmPBSN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_zy0zSOtn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_YUvSB0SS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ePFR2Nvx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_3IYGs99r_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_Dakk2SBY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AdURBmyo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_TXNbtBo3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mpIClhsL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_GJ7VAPyl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CW7zqlyo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_lvILrysQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_V4XUbADp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_V4XUbADp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lASL9QkA, HV_BINOP_MULTIPLY, 1, m, &cBinop_lASL9QkA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lASL9QkA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_iz9Fkarm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_iz9Fkarm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GJ7VAPyl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_3tA8x96i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_SL6VMwOs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SL6VMwOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jv88XOU2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PM5qDiCu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3FXmzAVj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5GQpMdZK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YCtuiaut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xhUzTUGE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_nulAHebh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qDHqT4d2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_eATlU9d7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PrspZkhR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ZYNdW2LA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YCvEqNzo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_anYA5mMH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7hJyqIRa, 0, m, &cVar_7hJyqIRa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_UxW7UVDN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4ULPxa4G, 1, m, &cVar_4ULPxa4G_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_h7dHeq7n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4ULPxa4G, 0, m, &cVar_4ULPxa4G_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_DyEo7H1S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2qXOByvj, 0, m, &cVar_2qXOByvj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_5GQpMdZK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YCtuiaut, HV_BINOP_MULTIPLY, 0, m, &cBinop_YCtuiaut_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_3FXmzAVj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nulAHebh, HV_BINOP_MULTIPLY, 0, m, &cBinop_nulAHebh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_PM5qDiCu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eATlU9d7, HV_BINOP_MULTIPLY, 0, m, &cBinop_eATlU9d7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_jv88XOU2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZYNdW2LA, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZYNdW2LA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_y1Qr0jH1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tIpIn8HP, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_u8iBxlwP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ow1augDd, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_oQczyZkS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dHcqEDuZ, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_i20ftTSv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TiXqE19e, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_XJ2nqOcQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PKPN8mEC, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_2r4S7rxl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_BPTGG8TX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_BPTGG8TX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_07sTpVm7, HV_BINOP_DIVIDE, 1, m, &cBinop_07sTpVm7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gx58SQk5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_kaGpyggp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_AF4ILlN8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_6vETIIAG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_kaGpyggp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AF4ILlN8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_07sTpVm7, HV_BINOP_DIVIDE, 0, m, &cBinop_07sTpVm7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_gx58SQk5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6vETIIAG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_07sTpVm7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QKP9DHkh, HV_BINOP_MULTIPLY, 1, m, &cBinop_QKP9DHkh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QKP9DHkh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0O7KDqWq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zsOIaVq2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_c06O5uKe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HluzoOqP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_QhcGhDuy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_riv3wyoQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_lFIHyzrr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_u9JGbdNg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_u9JGbdNg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QKP9DHkh, HV_BINOP_MULTIPLY, 0, m, &cBinop_QKP9DHkh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SOmrYKwE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_8m5w1Zj8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8m5w1Zj8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ymbjhdfz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_MX9rNfrF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LW8cQhKB, HV_BINOP_MULTIPLY, 1, m, &cBinop_LW8cQhKB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_hBrMwT5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Zc62rMtO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Zc62rMtO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_MX9rNfrF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_bOjmZud3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_nIPjUoZI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nIPjUoZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1qLkP5hC, HV_BINOP_MULTIPLY, 1, m, &cBinop_1qLkP5hC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SrVlbKAy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zbV5CKEN, HV_BINOP_MULTIPLY, 1, m, &cBinop_zbV5CKEN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_7kxuw08h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_uvrP7x0p_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uvrP7x0p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_SrVlbKAy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_54FzBVlf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PmospOX5, 1, m, &cVar_PmospOX5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_at2VCn1u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KncS2Zeu, HV_BINOP_MULTIPLY, 1, m, &cBinop_KncS2Zeu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_hJw13lGE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_zcJEy9Vi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zcJEy9Vi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1gE7u8rn, HV_BINOP_MULTIPLY, 1, m, &cBinop_1gE7u8rn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_PmospOX5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EgWkc4ar_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_t1G2JKG0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9cp1ngiQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_lFIHyzrr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zJKmyn75_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_ekx1ZD06_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_SOmrYKwE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_0O7KDqWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_c06O5uKe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_zsOIaVq2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_QhcGhDuy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_HluzoOqP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rqJJ1gSt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_riv3wyoQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SEnG2PZe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_4DIIpHY6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xGsLeFuP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_Ymbjhdfz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_yvIy6Mpc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yvIy6Mpc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HRIF1mpM, HV_BINOP_MULTIPLY, 1, m, &cBinop_HRIF1mpM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HRIF1mpM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_bsB62Eyh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bsB62Eyh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4DIIpHY6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_EgWkc4ar_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Mn3wknQV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Mn3wknQV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dpou6QPm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FbW8PKly_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IhWPGF3F_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AIHb91u5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XvDFkBhw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Y216i1hl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_LW8cQhKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_y1Qr0jH1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_1qLkP5hC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u8iBxlwP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_zbV5CKEN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oQczyZkS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_KncS2Zeu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i20ftTSv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_1gE7u8rn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XJ2nqOcQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_yfIFdweO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ekx1ZD06, 1, m, &cVar_ekx1ZD06_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ULxEVyB6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_t1G2JKG0, 0, m, &cVar_t1G2JKG0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_XvDFkBhw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1qLkP5hC, HV_BINOP_MULTIPLY, 0, m, &cBinop_1qLkP5hC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_FbW8PKly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1gE7u8rn, HV_BINOP_MULTIPLY, 0, m, &cBinop_1gE7u8rn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Y216i1hl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LW8cQhKB, HV_BINOP_MULTIPLY, 0, m, &cBinop_LW8cQhKB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_IhWPGF3F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KncS2Zeu, HV_BINOP_MULTIPLY, 0, m, &cBinop_KncS2Zeu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_dpou6QPm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_AIHb91u5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zbV5CKEN, HV_BINOP_MULTIPLY, 0, m, &cBinop_zbV5CKEN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_9cp1ngiQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ekx1ZD06, 0, m, &cVar_ekx1ZD06_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_zJKmyn75_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PmospOX5, 0, m, &cVar_PmospOX5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZGFUg7b7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ItfYA8by, 1, m, &cIf_ItfYA8by_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_FMqEDwfK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_KWNJJsPO, m);
}

void Heavy_WSTD_FL3NGR::cBinop_bX4CdJGR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FMqEDwfK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_OJ9wNvHw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ItfYA8by, 0, m, &cIf_ItfYA8by_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_B29G3qW3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xpVYQLXk, 0, m, &cSlice_xpVYQLXk_sendMessage);
      break;
    }
    default: {
      cSwitchcase_qe0KRmn8_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_xpVYQLXk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_RU2jI1EC_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_RU2jI1EC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_T29lSpyH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RU2jI1EC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_RU2jI1EC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NfbA0M8R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_00slYsaz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_oDkSP8SO_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_qKDyVsKA, 0, m, &cIf_qKDyVsKA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_qKDyVsKA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_OEff6wQF_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_96UeIy62_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_RPXdpnqK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_KxfgylPb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_gttbDpIS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_n4DMvizB, HV_BINOP_POW, 0, m, &cBinop_n4DMvizB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_n4DMvizB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0s63YwLc, 0, m, &cIf_0s63YwLc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vwD2ZH9r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_eaxIoRTv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_1nWcmkQe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_96UeIy62, 0, m, &cIf_96UeIy62_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ZBhnoci1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_lfeRsMIC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lfeRsMIC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_96UeIy62, 1, m, &cIf_96UeIy62_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KxfgylPb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_vwD2ZH9r_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_RPXdpnqK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_0s63YwLc, 0, m, &cIf_0s63YwLc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eaxIoRTv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_n4DMvizB, HV_BINOP_POW, 1, m, &cBinop_n4DMvizB_sendMessage);
  cMsg_gttbDpIS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_0s63YwLc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_53TgzYsS, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_oDkSP8SO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qKDyVsKA, 1, m, &cIf_qKDyVsKA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OEff6wQF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bphjMkLM, HV_BINOP_GREATER_THAN, 1, m, &cBinop_bphjMkLM_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_jJwXIGYY, HV_BINOP_EQ, 1, m, &cBinop_jJwXIGYY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_K2tZ1yyv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Wdrhlh4q, HV_BINOP_ADD, 0, m, &cBinop_Wdrhlh4q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Wdrhlh4q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZBhnoci1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1nWcmkQe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bphjMkLM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0s63YwLc, 1, m, &cIf_0s63YwLc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jJwXIGYY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R9AkEobp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_R9AkEobp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_53TgzYsS, m);
}

void Heavy_WSTD_FL3NGR::cCast_FBcWbFUQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K2tZ1yyv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_6nyoiJiU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Wdrhlh4q, HV_BINOP_ADD, 1, m, &cBinop_Wdrhlh4q_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bphjMkLM, HV_BINOP_GREATER_THAN, 0, m, &cBinop_bphjMkLM_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_jJwXIGYY, HV_BINOP_EQ, 0, m, &cBinop_jJwXIGYY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_j6Ac0H98_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_00slYsaz, 0, m, &cVar_00slYsaz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_ACgbwoi4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_mfzhUQ4p_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_7ur46vuH, 0, m, &cIf_7ur46vuH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_7ur46vuH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_dffvXFoQ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_fwifERYr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_HZPzJ23d_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_y0w3jPpx_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_kRWUjdlP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HmquPZYx, HV_BINOP_POW, 0, m, &cBinop_HmquPZYx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HmquPZYx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xZEeHCfe, 0, m, &cIf_xZEeHCfe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lsi8Q80T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_hTIzNLAf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_nCx1PDEM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fwifERYr, 0, m, &cIf_fwifERYr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_hS8UqcSU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_5Zbq7B5l_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5Zbq7B5l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fwifERYr, 1, m, &cIf_fwifERYr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_y0w3jPpx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_lsi8Q80T_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_HZPzJ23d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_xZEeHCfe, 0, m, &cIf_xZEeHCfe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hTIzNLAf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HmquPZYx, HV_BINOP_POW, 1, m, &cBinop_HmquPZYx_sendMessage);
  cMsg_kRWUjdlP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_xZEeHCfe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_DVqzanYo_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5iMdWQhM_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_dhl34e4W_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_mfzhUQ4p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7ur46vuH, 1, m, &cIf_7ur46vuH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dffvXFoQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KV3yGmMp, HV_BINOP_GREATER_THAN, 1, m, &cBinop_KV3yGmMp_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_pf6BXP0z, HV_BINOP_EQ, 1, m, &cBinop_pf6BXP0z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_s5yHJShs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_sukBkoVE, HV_BINOP_ADD, 0, m, &cBinop_sukBkoVE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sukBkoVE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hS8UqcSU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nCx1PDEM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KV3yGmMp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xZEeHCfe, 1, m, &cIf_xZEeHCfe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pf6BXP0z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QeAH1QFE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_QeAH1QFE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_DVqzanYo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5iMdWQhM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_dhl34e4W_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_m4vqagBK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sukBkoVE, HV_BINOP_ADD, 1, m, &cBinop_sukBkoVE_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_KV3yGmMp, HV_BINOP_GREATER_THAN, 0, m, &cBinop_KV3yGmMp_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_pf6BXP0z, HV_BINOP_EQ, 0, m, &cBinop_pf6BXP0z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_zNpxPkAH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ACgbwoi4, 0, m, &cVar_ACgbwoi4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_LDbFqicA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_s5yHJShs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_if1PZSMR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_H7EIa4QD_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_JbNuB8C7, 0, m, &cIf_JbNuB8C7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_JbNuB8C7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_VZq70zB4_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_AUHUhe2o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_wTg7Tpu0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_PJKSNhX3_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_zaFRj8ba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_FSybD9MD, HV_BINOP_POW, 0, m, &cBinop_FSybD9MD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FSybD9MD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PPt6JkYv, 0, m, &cIf_PPt6JkYv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mETTYeWE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_bxQpZ4o8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_iSYmuqom_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AUHUhe2o, 0, m, &cIf_AUHUhe2o_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_kjHGc1El_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_y6GjOGVH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_y6GjOGVH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AUHUhe2o, 1, m, &cIf_AUHUhe2o_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PJKSNhX3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_mETTYeWE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_wTg7Tpu0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_PPt6JkYv, 0, m, &cIf_PPt6JkYv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bxQpZ4o8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FSybD9MD, HV_BINOP_POW, 1, m, &cBinop_FSybD9MD_sendMessage);
  cMsg_zaFRj8ba_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_PPt6JkYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_niiSCNdH, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_H7EIa4QD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JbNuB8C7, 1, m, &cIf_JbNuB8C7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VZq70zB4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_upkjiwpw, HV_BINOP_GREATER_THAN, 1, m, &cBinop_upkjiwpw_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7G7gT3oJ, HV_BINOP_EQ, 1, m, &cBinop_7G7gT3oJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_J69Er2ZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_PENM6l6Z, HV_BINOP_ADD, 0, m, &cBinop_PENM6l6Z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PENM6l6Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kjHGc1El_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iSYmuqom_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_upkjiwpw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PPt6JkYv, 1, m, &cIf_PPt6JkYv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7G7gT3oJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_J0DTXFoa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_J0DTXFoa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_niiSCNdH, m);
}

void Heavy_WSTD_FL3NGR::cCast_BCpqIXZN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PENM6l6Z, HV_BINOP_ADD, 1, m, &cBinop_PENM6l6Z_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_upkjiwpw, HV_BINOP_GREATER_THAN, 0, m, &cBinop_upkjiwpw_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7G7gT3oJ, HV_BINOP_EQ, 0, m, &cBinop_7G7gT3oJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_BhOwUkE3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_J69Er2ZB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_ax2gzxZp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_if1PZSMR, 0, m, &cVar_if1PZSMR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_EJ0ypq09_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_dgz8F2dt, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cSwitchcase_0ncQGqH7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_fZIG3nw5, 0, m, &cSlice_fZIG3nw5_sendMessage);
      break;
    }
    default: {
      cSwitchcase_8bbX8q7p_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_fZIG3nw5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_2ddmJ6NO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_2ddmJ6NO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_mHH8JuHL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2ddmJ6NO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_2ddmJ6NO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uO5NjQaD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_8bbX8q7p_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_RQF2Ip6s, 0, m, &cSlice_RQF2Ip6s_sendMessage);
      break;
    }
    default: {
      cSwitchcase_B29G3qW3_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_RQF2Ip6s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_oghOTAt3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_oghOTAt3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_JrDMldfC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oghOTAt3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_oghOTAt3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DsuyVb0v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_qe0KRmn8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4mUInMmZ, 0, m, &cSlice_4mUInMmZ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_X5KkAMB3_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_4mUInMmZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_O2t8mfWe_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_O2t8mfWe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_5ThPzORN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_O2t8mfWe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_O2t8mfWe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_02PNQ4jX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_X5KkAMB3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_uZKuhP2f, 0, m, &cSlice_uZKuhP2f_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_uZKuhP2f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_o1h9iLqR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_o1h9iLqR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_ln71GCMl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_o1h9iLqR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_o1h9iLqR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VoUCMCif_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_V7FBH2iC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ywq6AxvP, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_VdUYDQGG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AVUbRAag, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_z1sykArZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zdLfJnDu, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_nLkm2dRE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1wocVNbL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_6I0DCmjv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3IayYz1c, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_RHLR2iDC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YXr3wJJJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_YXr3wJJJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5EXqRa5y, HV_BINOP_DIVIDE, 1, m, &cBinop_5EXqRa5y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GSD5LcGp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_Blt3kzhl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_RS7dNnej_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_2rTdPbYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Blt3kzhl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RS7dNnej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5EXqRa5y, HV_BINOP_DIVIDE, 0, m, &cBinop_5EXqRa5y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_GSD5LcGp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2rTdPbYt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_5EXqRa5y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IlzXAO9a, HV_BINOP_MULTIPLY, 1, m, &cBinop_IlzXAO9a_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_IlzXAO9a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_flQb198w_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_I4PoA57j_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_ttAboOdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zce7Z3WG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_RwhaWxn5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HwEj6oJA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_UjRflKqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_xChAUj1g_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xChAUj1g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IlzXAO9a, HV_BINOP_MULTIPLY, 0, m, &cBinop_IlzXAO9a_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3pBhYc6H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_cNaEkJk4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cNaEkJk4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TdZkVmx6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_J2EHrrKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Jd8o1QHa, 1, m, &cVar_Jd8o1QHa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_Jd8o1QHa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rUPwX2L5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_10K3rtIw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ldNyTlnY, HV_BINOP_MULTIPLY, 1, m, &cBinop_ldNyTlnY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cXHtQGkN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_10K3rtIw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KxBn1lnd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_PS2mcj2a_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PS2mcj2a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6qK4O2Kc, HV_BINOP_MULTIPLY, 1, m, &cBinop_6qK4O2Kc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RGghAm6M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Wii2YnOy, HV_BINOP_MULTIPLY, 1, m, &cBinop_Wii2YnOy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UFIAcK54_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_RGghAm6M_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zPVxKvL3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xwakBIwY, HV_BINOP_MULTIPLY, 1, m, &cBinop_xwakBIwY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_oHr9YDQB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_DrlraDsf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DrlraDsf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dlemU0pV, HV_BINOP_MULTIPLY, 1, m, &cBinop_dlemU0pV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_RhIBlrJS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rAFcSAWy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_UjRflKqO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4zHDaXeg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_copmYxf4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_3pBhYc6H_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_I4PoA57j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_RwhaWxn5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_flQb198w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_ttAboOdo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_zce7Z3WG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7neyIP7L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_HwEj6oJA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VN1SwWov_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_g5NJhOaE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Ap026MqY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_TdZkVmx6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_NMf1WEoF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NMf1WEoF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XVmWVm6C, HV_BINOP_MULTIPLY, 1, m, &cBinop_XVmWVm6C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XVmWVm6C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zbJ6jDCz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zbJ6jDCz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_g5NJhOaE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_rUPwX2L5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_WK7COpii_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WK7COpii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TtvCCEgh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_N1w3edEO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7UsYasKd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RSuikFbb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Gqtw5GMu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_O6Fdj116_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ldNyTlnY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_V7FBH2iC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_6qK4O2Kc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VdUYDQGG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Wii2YnOy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_z1sykArZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_xwakBIwY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nLkm2dRE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_dlemU0pV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6I0DCmjv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_O2fNP7s1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RhIBlrJS, 0, m, &cVar_RhIBlrJS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_XQ8HvZdq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_copmYxf4, 1, m, &cVar_copmYxf4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_N1w3edEO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dlemU0pV, HV_BINOP_MULTIPLY, 0, m, &cBinop_dlemU0pV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_O6Fdj116_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ldNyTlnY, HV_BINOP_MULTIPLY, 0, m, &cBinop_ldNyTlnY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_TtvCCEgh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_RSuikFbb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Wii2YnOy, HV_BINOP_MULTIPLY, 0, m, &cBinop_Wii2YnOy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Gqtw5GMu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6qK4O2Kc, HV_BINOP_MULTIPLY, 0, m, &cBinop_6qK4O2Kc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_7UsYasKd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xwakBIwY, HV_BINOP_MULTIPLY, 0, m, &cBinop_xwakBIwY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_4zHDaXeg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Jd8o1QHa, 0, m, &cVar_Jd8o1QHa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_rAFcSAWy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_copmYxf4, 0, m, &cVar_copmYxf4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_2Jo143KL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yHCuHwZp, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_p0Z454fY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MQYyz720, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_A7h0gueQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uqtqW54G, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_NNUhTy9R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8ujU2d8E, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_L5oaNE6x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RTkjh8zx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_RTkjh8zx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5Rxs4bnI, HV_BINOP_DIVIDE, 1, m, &cBinop_5Rxs4bnI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Gb26Kqcn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_uz705XQQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_6TJ0aPLF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_5iOhV9a3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_uz705XQQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6TJ0aPLF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5Rxs4bnI, HV_BINOP_DIVIDE, 0, m, &cBinop_5Rxs4bnI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Gb26Kqcn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5iOhV9a3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_5Rxs4bnI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gcUCwyKZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_gcUCwyKZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gcUCwyKZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rch4xKlS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ako8Nwvc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_6YOtcWVp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_eub2Ic70_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_oZbUwIwW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qxsHBXpz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_JuBNCHvz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_GsOyIFxl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GsOyIFxl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gcUCwyKZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_gcUCwyKZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HS0HLJ7A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_LVeJfdAU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_LVeJfdAU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1zWVq0ch_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_kq6cjIP9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oSvEIovD, HV_BINOP_MULTIPLY, 1, m, &cBinop_oSvEIovD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xQnRJskL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_euOTvfzU, 1, m, &cVar_euOTvfzU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YLgIQzH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bbN4vb2d, HV_BINOP_MULTIPLY, 1, m, &cBinop_bbN4vb2d_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_OelfOI6Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_uOo0qBQF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uOo0qBQF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Oh0efpQ1, HV_BINOP_MULTIPLY, 1, m, &cBinop_Oh0efpQ1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_euOTvfzU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SqMfg5Vs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_tUJulrVF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4Q9e6Mwd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_JuBNCHvz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tgQQ8XBg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_5tgF5oNv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_HS0HLJ7A_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Ako8Nwvc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_oZbUwIwW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_rch4xKlS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_6YOtcWVp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_eub2Ic70_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2yJDQU8R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_qxsHBXpz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sDdzILNU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_4M3DEf1b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Nt4zBirt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_1zWVq0ch_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_SStNxivR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SStNxivR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tV7Ee1Vt, HV_BINOP_MULTIPLY, 1, m, &cBinop_tV7Ee1Vt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tV7Ee1Vt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_XaiTl1qZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XaiTl1qZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4M3DEf1b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_SqMfg5Vs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_VMW7xesu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VMW7xesu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4CHV8aFs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1SAxCq9Y_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZotgYYtv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dJBBAUht_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_a5blsDCX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2Jo143KL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_oSvEIovD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_p0Z454fY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_bbN4vb2d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_A7h0gueQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Oh0efpQ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NNUhTy9R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_Mt4Qtu0g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5tgF5oNv, 1, m, &cVar_5tgF5oNv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_VTw2lEdW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tUJulrVF, 0, m, &cVar_tUJulrVF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_tgQQ8XBg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_euOTvfzU, 0, m, &cVar_euOTvfzU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_4Q9e6Mwd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5tgF5oNv, 0, m, &cVar_5tgF5oNv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_1SAxCq9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bbN4vb2d, HV_BINOP_MULTIPLY, 0, m, &cBinop_bbN4vb2d_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_4CHV8aFs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Oh0efpQ1, HV_BINOP_MULTIPLY, 0, m, &cBinop_Oh0efpQ1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_dJBBAUht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a5blsDCX, HV_BINOP_MULTIPLY, 0, m, &cBinop_a5blsDCX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ZotgYYtv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oSvEIovD, HV_BINOP_MULTIPLY, 0, m, &cBinop_oSvEIovD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_eT9b5Dw1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PNKDZY61, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_8hblh4Qm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3cH4PAfL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_LqcmdnLx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QgPUefYU, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_oh0QP244_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JeYDHWuI, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_IxEA2H8s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EX2dHiPm, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_utKYx5pJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_nEoNcKuA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_nEoNcKuA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vFq7Gesm, HV_BINOP_DIVIDE, 1, m, &cBinop_vFq7Gesm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_p0AedqF4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_2tLrjo4K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_bd2lnaIy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_CmTTbk6e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_2tLrjo4K_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bd2lnaIy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vFq7Gesm, HV_BINOP_DIVIDE, 0, m, &cBinop_vFq7Gesm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_p0AedqF4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CmTTbk6e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_vFq7Gesm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NkNE0wm4, HV_BINOP_MULTIPLY, 1, m, &cBinop_NkNE0wm4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NkNE0wm4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gFTdZyAV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_w9kOp23U_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_ghRyQNbo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BucPPUgO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_zd7S3kDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LAr416wu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_SMckhQMO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_M9vY8Y10_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_M9vY8Y10_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NkNE0wm4, HV_BINOP_MULTIPLY, 0, m, &cBinop_NkNE0wm4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_h8WhDYKC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_tUQ215Du_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tUQ215Du_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jcFNKugI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_dUHvhy3L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B61IJChv, HV_BINOP_MULTIPLY, 1, m, &cBinop_B61IJChv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ByhIsGKX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_kqnG67y6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kqnG67y6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_dUHvhy3L_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_IOtaqWmK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_2VApYS0Z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2VApYS0Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YNgWADib, HV_BINOP_MULTIPLY, 1, m, &cBinop_YNgWADib_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7G1jzMvI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jXrC5xj5, HV_BINOP_MULTIPLY, 1, m, &cBinop_jXrC5xj5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_F6gkLd3d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_l6Wm1TCw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_l6Wm1TCw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_7G1jzMvI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TWuHyRLT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qD5k4uol, 1, m, &cVar_qD5k4uol_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RiDMJ4jp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YYxAnRC1, HV_BINOP_MULTIPLY, 1, m, &cBinop_YYxAnRC1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_moSmmCjp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Z03IfPLB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Z03IfPLB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7VmSyPW8, HV_BINOP_MULTIPLY, 1, m, &cBinop_7VmSyPW8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_qD5k4uol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5Axxig5m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_UqS0h04a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_g18pVbtP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_SMckhQMO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iCXQwJYs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_3G0j3Pn1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_h8WhDYKC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_gFTdZyAV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_ghRyQNbo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_w9kOp23U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_zd7S3kDp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_BucPPUgO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tPAgd0Eu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_LAr416wu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Tr2UmoBy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_C5LHaqcP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DWRBdvb8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_jcFNKugI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_qPvu07HF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qPvu07HF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_unwdamnY, HV_BINOP_MULTIPLY, 1, m, &cBinop_unwdamnY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_unwdamnY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_3BuOR1FP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3BuOR1FP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_C5LHaqcP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_5Axxig5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_3FLRmUx1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3FLRmUx1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EDsSufQt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oTjboNMH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rE9vyUif_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_i22nhyPy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uKUJ0dKJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B935hJkr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_B61IJChv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eT9b5Dw1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_YNgWADib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8hblh4Qm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_jXrC5xj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LqcmdnLx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_YYxAnRC1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oh0QP244_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_7VmSyPW8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IxEA2H8s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_S57kVeOn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3G0j3Pn1, 1, m, &cVar_3G0j3Pn1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_H6CiymQo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UqS0h04a, 0, m, &cVar_UqS0h04a_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_oTjboNMH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7VmSyPW8, HV_BINOP_MULTIPLY, 0, m, &cBinop_7VmSyPW8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_B935hJkr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B61IJChv, HV_BINOP_MULTIPLY, 0, m, &cBinop_B61IJChv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_uKUJ0dKJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YNgWADib, HV_BINOP_MULTIPLY, 0, m, &cBinop_YNgWADib_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_EDsSufQt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_rE9vyUif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YYxAnRC1, HV_BINOP_MULTIPLY, 0, m, &cBinop_YYxAnRC1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_i22nhyPy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jXrC5xj5, HV_BINOP_MULTIPLY, 0, m, &cBinop_jXrC5xj5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_g18pVbtP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3G0j3Pn1, 0, m, &cVar_3G0j3Pn1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_iCXQwJYs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qD5k4uol, 0, m, &cVar_qD5k4uol_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DVqzanYo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EJ0ypq09, 1, m, &cIf_EJ0ypq09_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_nZ2KgEQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_dgz8F2dt, m);
}

void Heavy_WSTD_FL3NGR::cBinop_5iMdWQhM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nZ2KgEQL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_dhl34e4W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EJ0ypq09, 0, m, &cIf_EJ0ypq09_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_6922t5lB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XCKaxUVY, HV_BINOP_DIVIDE, 0, m, &cBinop_XCKaxUVY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_iJIGqCQu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1x5hJHaB, HV_BINOP_DIVIDE, 1, m, &cBinop_1x5hJHaB_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_XCKaxUVY, HV_BINOP_DIVIDE, 1, m, &cBinop_XCKaxUVY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_urkgCgKi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QcMOR4u8, HV_BINOP_DIVIDE, 0, m, &cBinop_QcMOR4u8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_hKC4AjX0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QcMOR4u8, HV_BINOP_DIVIDE, 1, m, &cBinop_QcMOR4u8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_9o8RVllB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1x5hJHaB, HV_BINOP_DIVIDE, 0, m, &cBinop_1x5hJHaB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_csyhnKG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iJIGqCQu, 0, m, &cVar_iJIGqCQu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_18hxzrYl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6922t5lB, 0, m, &cVar_6922t5lB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1x5hJHaB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_urkgCgKi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XCKaxUVY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_hKC4AjX0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QcMOR4u8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_TT9wRS4C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_CkAnjoAJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_c51ZW1Y8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mhpixp2f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_fC5TXsYU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TT9wRS4C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_mhpixp2f_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fC5TXsYU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_CkAnjoAJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_c51ZW1Y8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HXJvfHsE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_JnMV7MZa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EFxL82Db_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_9JJSau5p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3nOkCdxm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_1utfuWq1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OhYTwle5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_gVFrC7dK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9Ehgjmjb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_bnh68LGW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8ER2YznA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_HLZRSZri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SgPTrPQ0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_AMlioFPJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_A9K3sUBe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_tKWt2ajs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uTXxA7mj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_Hu8EM7Hg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f4uVIEbf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_Oz0vNkfe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZDZ9H9tj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_clezGTKR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1BcecEjD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_smYM9KJH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5tZwspV8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_yFpUjNiK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ka4wqwvi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ka4wqwvi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_LDEIBBDI, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_XdeFfpTh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_vWKCMV59_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_vWKCMV59_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_JW9kcCYw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_dfMh03Wz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GBebxnzj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_0scFJ35A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_UI2LoxcK_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_lqdZnbMS, m);
}

void Heavy_WSTD_FL3NGR::cBinop_JW9kcCYw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_mDjiCuNu, m);
}

void Heavy_WSTD_FL3NGR::cMsg_GBebxnzj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0scFJ35A_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UI2LoxcK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_3h7z1rqd, m);
}

void Heavy_WSTD_FL3NGR::cMsg_P9wkoc9S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0kshU2jO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_0kshU2jO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_aK28wH7a_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_Td7Gkmr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EBrChv69_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_pYVEksR0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_tpUGUwIz_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_4xjwMElb, m);
}

void Heavy_WSTD_FL3NGR::cBinop_aK28wH7a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_MdRe3iAQ, m);
}

void Heavy_WSTD_FL3NGR::cMsg_EBrChv69_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_pYVEksR0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tpUGUwIz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_msnUTrtq, m);
}

void Heavy_WSTD_FL3NGR::cBinop_3oDTXjqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_XrQF5Oo0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XrQF5Oo0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_K7YUA1cW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_g0JCYJaf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fF5g5cU8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_5FywPhFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HkOCtIpE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_K7YUA1cW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_JDhKXX0i_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JDhKXX0i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kgmr4Nkw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Oi4k4a5i_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_kgmr4Nkw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_T6SBrHa8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Oi4k4a5i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kDk6VwOE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_T6SBrHa8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_g6zWGI9G_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_kDk6VwOE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_T3JMlCCN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_T3JMlCCN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_l7WIOkb5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_g6zWGI9G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_g0JCYJaf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_l7WIOkb5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_5FywPhFj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZIKadSao_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_mfOq8DmE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mfOq8DmE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zz8RGmjX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_NKIp07hU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_sbefJ6TR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_sbefJ6TR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_0EkAMkEa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_57pXT9o4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_57pXT9o4, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6LxN2jTB, 0, m, &cDelay_6LxN2jTB_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_57pXT9o4, 0, m, &cDelay_57pXT9o4_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Qdm35qSU, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_6LxN2jTB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6LxN2jTB, m);
  cMsg_9Jblk4wk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_sK8rRdj0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_sV738Fjf_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_30vArARI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MOFlXymy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_EoJSgAHR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DhLC6vQk_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_57pXT9o4, 2, m, &cDelay_57pXT9o4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pTURQ2eT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_MOFlXymy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_EoJSgAHR, 0, m, &hTable_EoJSgAHR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0EkAMkEa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_30vArARI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_9Jblk4wk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_EoJSgAHR, 0, m, &hTable_EoJSgAHR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_pTURQ2eT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_57pXT9o4, 0, m, &cDelay_57pXT9o4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_DhLC6vQk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_6LxN2jTB, 2, m, &cDelay_6LxN2jTB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_sV738Fjf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Qdm35qSU, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_K7Ka3fP9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_XWeff781_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_XWeff781_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_deZFc9cD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_FLHIVKp0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FLHIVKp0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_f3OY4ixW, 0, m, &cDelay_f3OY4ixW_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FLHIVKp0, 0, m, &cDelay_FLHIVKp0_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_FdRymPeH, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_f3OY4ixW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_f3OY4ixW, m);
  cMsg_i4oIlJai_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_euW9dSRN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_6LHNGUlm_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_k4ndIuvw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aXbebh2i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_13qWpMwN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7zQ856AS_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FLHIVKp0, 2, m, &cDelay_FLHIVKp0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AZUttaNI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_aXbebh2i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_13qWpMwN, 0, m, &hTable_13qWpMwN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_deZFc9cD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_k4ndIuvw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_i4oIlJai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_13qWpMwN, 0, m, &hTable_13qWpMwN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_AZUttaNI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_FLHIVKp0, 0, m, &cDelay_FLHIVKp0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_7zQ856AS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_f3OY4ixW, 2, m, &cDelay_f3OY4ixW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_6LHNGUlm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_FdRymPeH, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_XFYEVGHw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Twl2GDLo, HV_BINOP_MULTIPLY, 0, m, &cBinop_Twl2GDLo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_nJKwzcGT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VjugVGd5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_VjugVGd5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rYyjZ3uJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Twl2GDLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_BMlGEK2a_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AYPmb81g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Twl2GDLo, HV_BINOP_MULTIPLY, 1, m, &cBinop_Twl2GDLo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_rYyjZ3uJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_AYPmb81g_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BMlGEK2a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Ft3f9BNY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Ft3f9BNY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_5sRlPJR7_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Ahi3MdNM, m);
}

void Heavy_WSTD_FL3NGR::cBinop_5sRlPJR7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_B1eu3pPg, m);
}

void Heavy_WSTD_FL3NGR::cVar_eZz5MX1Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lYnjfUgc, HV_BINOP_MULTIPLY, 0, m, &cBinop_lYnjfUgc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_qoSEoF7T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Qrr7HvrG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_Qrr7HvrG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FI9RcTEp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_lYnjfUgc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Z9FQExNu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KchiqyCk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lYnjfUgc, HV_BINOP_MULTIPLY, 1, m, &cBinop_lYnjfUgc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_FI9RcTEp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_KchiqyCk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Z9FQExNu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_baY9kXsg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_baY9kXsg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_8CmbkyqN_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_fN3kf1uO, m);
}

void Heavy_WSTD_FL3NGR::cBinop_8CmbkyqN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_cBIrdxD2, m);
}

void Heavy_WSTD_FL3NGR::cMsg_zz8RGmjX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Er9mFktG, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_A6g8i7DY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_9KofSwvd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_xVjTtE19_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_A6g8i7DY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_hQgLrcOK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_2G2ZGa9a_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_akcsSefo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_zZZ0JwJ7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zZZ0JwJ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2zl2cljS, HV_BINOP_MULTIPLY, 1, m, &cBinop_2zl2cljS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2G2ZGa9a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_akcsSefo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2zl2cljS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7H9N2lCQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_9KofSwvd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2zl2cljS, HV_BINOP_MULTIPLY, 0, m, &cBinop_2zl2cljS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_7H9N2lCQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9DPu3hse, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_urMVncEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_wELplMrU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wELplMrU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hQgLrcOK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xVjTtE19_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_NZFs7ZyI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_guT9GLAH, 0, m, &cSlice_guT9GLAH_sendMessage);
      break;
    }
    default: {
      cSwitchcase_mmvusiGb_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_guT9GLAH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_0vi4sC3d_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_0vi4sC3d_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_ZDVTHBF0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0vi4sC3d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_0vi4sC3d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WDo5H596_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_mmvusiGb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_10XFUHWF, 0, m, &cSlice_10XFUHWF_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ezCKUgTp_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_10XFUHWF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JuIo8GCZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JuIo8GCZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_6cn2f5Rv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JuIo8GCZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_JuIo8GCZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_EShcuGGK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_ezCKUgTp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_CJo8KBxt, 0, m, &cSlice_CJo8KBxt_sendMessage);
      break;
    }
    default: {
      cSwitchcase_MXj8A8an_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_CJo8KBxt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_p3RKpme8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_p3RKpme8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_BYGLEnC6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_p3RKpme8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_p3RKpme8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CwzzB1GA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_MXj8A8an_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ajOBMZTX, 0, m, &cSlice_ajOBMZTX_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_ajOBMZTX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_y62ULKH3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_y62ULKH3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_xVwvHsDs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_y62ULKH3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_y62ULKH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hBiF29Ml_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_fF5g5cU8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kiiq6Xfo, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_HkOCtIpE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_if2KQ2Kj, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_p8KPC5s5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_8MkjSd7P_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8MkjSd7P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_pNHHKuqg, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_QZaCEKHH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0SZvz1nE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_0SZvz1nE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_NoeZQV8L_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_SXFFteIL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sd1VmPKk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_fmGh9CPv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_EJMtIr3n_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_BCV3gzcv, m);
}

void Heavy_WSTD_FL3NGR::cBinop_NoeZQV8L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_SuvAPki8, m);
}

void Heavy_WSTD_FL3NGR::cMsg_sd1VmPKk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fmGh9CPv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_EJMtIr3n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Slkl1VYZ, m);
}

void Heavy_WSTD_FL3NGR::cMsg_jPd1EQsJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WVCcMxKD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_WVCcMxKD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_VRxyo83f_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_8KdTyqe7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e1efz5Gd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_PVqssfMJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_01QhHxMu_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Nik7EkMI, m);
}

void Heavy_WSTD_FL3NGR::cBinop_VRxyo83f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_0jsZbEe2, m);
}

void Heavy_WSTD_FL3NGR::cMsg_e1efz5Gd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PVqssfMJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_01QhHxMu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_vrUgYlqu, m);
}

void Heavy_WSTD_FL3NGR::cBinop_rNJlCNJ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Dso1jRGn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Dso1jRGn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_gSlab1mr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_b0x0uf4i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yUxmmT4o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_ZlXYLEqH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7hFBNdhO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_gSlab1mr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_h8vjCLtd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_h8vjCLtd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_q6ZP7LQL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_akMwvzlr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_akMwvzlr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QeRMOSIW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_q6ZP7LQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Mp7c3NoW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Mp7c3NoW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_sFPaH0z4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_QeRMOSIW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_oQrpSPRy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oQrpSPRy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_xekOX4HN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sFPaH0z4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_b0x0uf4i_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xekOX4HN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_ZlXYLEqH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FIYqgMhs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_FWdfZqLd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FWdfZqLd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DnAertwK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_7I3YwioG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_UjDsOCru_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_UjDsOCru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_NpOy44up_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_9A6P4h7h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9A6P4h7h, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bw9fqP2M, 0, m, &cDelay_bw9fqP2M_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_9A6P4h7h, 0, m, &cDelay_9A6P4h7h_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_BQqfwjtC, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_bw9fqP2M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bw9fqP2M, m);
  cMsg_961qrgE1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_Tg82F7fb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_DPZapogz_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_3XwaKkFl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ovQcabtT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_tY2Tok9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Xs5KT8bc_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_9A6P4h7h, 2, m, &cDelay_9A6P4h7h_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MwvxeifC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ovQcabtT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_tY2Tok9D, 0, m, &hTable_tY2Tok9D_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NpOy44up_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_3XwaKkFl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_961qrgE1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_tY2Tok9D, 0, m, &hTable_tY2Tok9D_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_MwvxeifC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9A6P4h7h, 0, m, &cDelay_9A6P4h7h_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Xs5KT8bc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_bw9fqP2M, 2, m, &cDelay_bw9fqP2M_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_DPZapogz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_BQqfwjtC, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_yPdpj9Mc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8xeZJRnQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_8xeZJRnQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_UWGcQqjy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_xXtvt9Q8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xXtvt9Q8, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_L8sK6si1, 0, m, &cDelay_L8sK6si1_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xXtvt9Q8, 0, m, &cDelay_xXtvt9Q8_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_pVuivMdQ, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_L8sK6si1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_L8sK6si1, m);
  cMsg_EVwGMks9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_YG98ocZ7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_UEPfwLON_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_XFBjEsrP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CkNi1VlK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_njrfB8je_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gFs2k06L_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xXtvt9Q8, 2, m, &cDelay_xXtvt9Q8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OB66Avev_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_CkNi1VlK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_njrfB8je, 0, m, &hTable_njrfB8je_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UWGcQqjy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_XFBjEsrP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_EVwGMks9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_njrfB8je, 0, m, &hTable_njrfB8je_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_OB66Avev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xXtvt9Q8, 0, m, &cDelay_xXtvt9Q8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_gFs2k06L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_L8sK6si1, 2, m, &cDelay_L8sK6si1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_UEPfwLON_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_pVuivMdQ, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_37gBMdge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YeP73Pve, HV_BINOP_MULTIPLY, 0, m, &cBinop_YeP73Pve_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_8b1gSw8w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dWFZUgzE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_dWFZUgzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Rlalj5zh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_YeP73Pve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_XHRQMI5f_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wO0uSOtx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YeP73Pve, HV_BINOP_MULTIPLY, 1, m, &cBinop_YeP73Pve_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Rlalj5zh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_wO0uSOtx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XHRQMI5f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_T9aFFwHs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_T9aFFwHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_nRPAfpw5_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_jUByUiC0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_nRPAfpw5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_AR1GpwfO, m);
}

void Heavy_WSTD_FL3NGR::cVar_7AfRTEIu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iSUessSP, HV_BINOP_MULTIPLY, 0, m, &cBinop_iSUessSP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_3wEkYHNT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JMh2qQ4z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_JMh2qQ4z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Gh1jAVQE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_iSUessSP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_977m3IsY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RnhlTV0N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iSUessSP, HV_BINOP_MULTIPLY, 1, m, &cBinop_iSUessSP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Gh1jAVQE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_RnhlTV0N_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_977m3IsY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_W4aCxTm6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_W4aCxTm6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_tzjX8pW0_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_G8cnrmSN, m);
}

void Heavy_WSTD_FL3NGR::cBinop_tzjX8pW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_JRcDXLjU, m);
}

void Heavy_WSTD_FL3NGR::cMsg_DnAertwK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sZXWE02r, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_EuglmixH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_HsgoK1oi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_iZfGkB5W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_EuglmixH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_GYO41S0k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_sokRORL0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HsmRGNtf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_1T4oO7Y0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1T4oO7Y0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fyWmDjA2, HV_BINOP_MULTIPLY, 1, m, &cBinop_fyWmDjA2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sokRORL0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_HsmRGNtf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fyWmDjA2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Hem9NnTc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_HsgoK1oi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fyWmDjA2, HV_BINOP_MULTIPLY, 0, m, &cBinop_fyWmDjA2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Hem9NnTc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sQJBthcd, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_ZTUSl10S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_smySucob_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_smySucob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GYO41S0k_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iZfGkB5W_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_S2YbT5Bl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_QIwSA4Qk, 0, m, &cSlice_QIwSA4Qk_sendMessage);
      break;
    }
    default: {
      cSwitchcase_pAzKqYkp_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_QIwSA4Qk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xBcmrr9l_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xBcmrr9l_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_mzs9ng0B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xBcmrr9l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_xBcmrr9l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Xq6jlpjh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_pAzKqYkp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_fd3nvtnM, 0, m, &cSlice_fd3nvtnM_sendMessage);
      break;
    }
    default: {
      cSwitchcase_RZ1YvGKG_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_fd3nvtnM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_7v0A3c92_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_7v0A3c92_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_ZHWMDjRh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7v0A3c92_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_7v0A3c92_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tTyhOArW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_RZ1YvGKG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_MtXw1Ywv, 0, m, &cSlice_MtXw1Ywv_sendMessage);
      break;
    }
    default: {
      cSwitchcase_bHYhHhC0_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_MtXw1Ywv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_EfiJvw6w_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_EfiJvw6w_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_v4wh0Ziv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EfiJvw6w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_EfiJvw6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pYfDZZVn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_bHYhHhC0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4fAUxgPP, 0, m, &cSlice_4fAUxgPP_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_4fAUxgPP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_SMreB7vl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_SMreB7vl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_bNABAef4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SMreB7vl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_SMreB7vl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_d2pC8NtJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_yUxmmT4o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HePiWqR1, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_7hFBNdhO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DcN9K9V8, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_3UwCYN6G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_1Igjw1vj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1Igjw1vj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_OO5lEkFL, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_O1HWoUYX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_gR3Yqyfu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_gR3Yqyfu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_HVK6OR5H_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_IA5A2U44_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JrdeKKKI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_54ELGwL8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_OB7CADli_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_R6VDCSVA, m);
}

void Heavy_WSTD_FL3NGR::cBinop_HVK6OR5H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Phqr5L9W, m);
}

void Heavy_WSTD_FL3NGR::cMsg_JrdeKKKI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_54ELGwL8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OB7CADli_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_4HQPB4a7, m);
}

void Heavy_WSTD_FL3NGR::cMsg_vvzLccHU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wzZZcW8L_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_wzZZcW8L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_VGcRK8Hm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_Y3q7XLHk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kcmhrR0b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_b2P2PJKG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_PpfamCXL_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_S1uJUz2k, m);
}

void Heavy_WSTD_FL3NGR::cBinop_VGcRK8Hm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_IDZopqVd, m);
}

void Heavy_WSTD_FL3NGR::cMsg_kcmhrR0b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_b2P2PJKG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PpfamCXL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_08hnKi59, m);
}

void Heavy_WSTD_FL3NGR::cBinop_owx52ADh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_kug5fz3d_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kug5fz3d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_nP8AmyiQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_vp663A5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NZyjPvFY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_sI8Ki01z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AK5vu7V8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_nP8AmyiQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_mRJ1dVrG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mRJ1dVrG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_koLKK0iY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xZDicBp6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_xZDicBp6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aHVRl1y3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_koLKK0iY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_M3yMa6Bq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_M3yMa6Bq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_RIEsqUK0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_aHVRl1y3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_CM9l0daZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CM9l0daZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_w4d2Gu0a_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RIEsqUK0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_vp663A5r_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_w4d2Gu0a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_sI8Ki01z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_glmnDYkC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_HprxKgTB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HprxKgTB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RQqagekJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_GH1bpU5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YprDVNzL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_YprDVNzL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_R4OgozSl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_KSqbWdfn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KSqbWdfn, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_4bC3Ivro, 0, m, &cDelay_4bC3Ivro_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_KSqbWdfn, 0, m, &cDelay_KSqbWdfn_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_S52q2reb, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_4bC3Ivro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4bC3Ivro, m);
  cMsg_dXVEG0HV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_vgvkgWmu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_NhI2kX2h_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_vB4cTiZo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_up76zI12_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_OHQ34Isc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8G2HWf1D_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_KSqbWdfn, 2, m, &cDelay_KSqbWdfn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PtvNusOf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_up76zI12_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_OHQ34Isc, 0, m, &hTable_OHQ34Isc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_R4OgozSl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_vB4cTiZo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_dXVEG0HV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_OHQ34Isc, 0, m, &hTable_OHQ34Isc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_PtvNusOf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KSqbWdfn, 0, m, &cDelay_KSqbWdfn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_8G2HWf1D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_4bC3Ivro, 2, m, &cDelay_4bC3Ivro_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_NhI2kX2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_S52q2reb, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_N65GHMll_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_AnFuMgix_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_AnFuMgix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_eHXXepvY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_TSnCbGh1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TSnCbGh1, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MAPajAOV, 0, m, &cDelay_MAPajAOV_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TSnCbGh1, 0, m, &cDelay_TSnCbGh1_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_3olcHRWz, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_MAPajAOV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MAPajAOV, m);
  cMsg_NrBKlWbL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_yPvJDLtI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_bpUDKfUB_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_G4EDwT9X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0RsfEggR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_qQFl8ajt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EtHVPo2C_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TSnCbGh1, 2, m, &cDelay_TSnCbGh1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ExNwWggW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_0RsfEggR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_qQFl8ajt, 0, m, &hTable_qQFl8ajt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eHXXepvY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_G4EDwT9X_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_NrBKlWbL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_qQFl8ajt, 0, m, &hTable_qQFl8ajt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ExNwWggW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TSnCbGh1, 0, m, &cDelay_TSnCbGh1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_EtHVPo2C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_MAPajAOV, 2, m, &cDelay_MAPajAOV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_bpUDKfUB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_3olcHRWz, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_CYZ8r3B0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vjo8DCJZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_vjo8DCJZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_oxcVBfyn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HuN8fMJy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_HuN8fMJy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xoLk3Gbn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_vjo8DCJZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_62IOagxp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cWAGrRey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vjo8DCJZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_vjo8DCJZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_xoLk3Gbn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_cWAGrRey_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_62IOagxp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_pQG4cQuA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pQG4cQuA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_BoL9uk3B_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_xb6P6MFO, m);
}

void Heavy_WSTD_FL3NGR::cBinop_BoL9uk3B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_5NVBgRkf, m);
}

void Heavy_WSTD_FL3NGR::cVar_wkJf00bk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_o5xgmV6u, HV_BINOP_MULTIPLY, 0, m, &cBinop_o5xgmV6u_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_xBXcz0av_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HAtxvAjJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_HAtxvAjJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ndh9dWLv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_o5xgmV6u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_xuhUJj6H_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4kfhjswk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_o5xgmV6u, HV_BINOP_MULTIPLY, 1, m, &cBinop_o5xgmV6u_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Ndh9dWLv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_4kfhjswk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xuhUJj6H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_QafNcvKD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QafNcvKD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_xYsOvWmA_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Hk5mAGKl, m);
}

void Heavy_WSTD_FL3NGR::cBinop_xYsOvWmA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_53ckMoCZ, m);
}

void Heavy_WSTD_FL3NGR::cMsg_RQqagekJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NiMhLQGl, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_Rb1KCRSr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_XqmrtxYJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_uOHVCWxP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_Rb1KCRSr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_7uiEOyxi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_eAeZbHRT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4DQemfmS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_eB8CJiWM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eB8CJiWM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xIabs3lK, HV_BINOP_MULTIPLY, 1, m, &cBinop_xIabs3lK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eAeZbHRT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_4DQemfmS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xIabs3lK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ej2ps75A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_XqmrtxYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xIabs3lK, HV_BINOP_MULTIPLY, 0, m, &cBinop_xIabs3lK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ej2ps75A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3KG0iEj1, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_hY65ZaRg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_1yBFHnrd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1yBFHnrd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7uiEOyxi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uOHVCWxP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_5jA0fbtP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Y7ZKB6JC, 0, m, &cSlice_Y7ZKB6JC_sendMessage);
      break;
    }
    default: {
      cSwitchcase_03IW4uHy_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_Y7ZKB6JC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Qcrt0O5e_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Qcrt0O5e_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_lTPBWCdW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Qcrt0O5e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_Qcrt0O5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZpU0P97T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_03IW4uHy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_GEKu7BAG, 0, m, &cSlice_GEKu7BAG_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ZTSIDYUk_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_GEKu7BAG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_RJWwSfK2_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_RJWwSfK2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_tX5uB8t6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RJWwSfK2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_RJWwSfK2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_S24bjmur_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_ZTSIDYUk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9WEf8QgO, 0, m, &cSlice_9WEf8QgO_sendMessage);
      break;
    }
    default: {
      cSwitchcase_sQeGDnLL_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_9WEf8QgO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xFGYbXYI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xFGYbXYI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_nzrziBGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xFGYbXYI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_xFGYbXYI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Ks4C5tR6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_sQeGDnLL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DadM4Hhq, 0, m, &cSlice_DadM4Hhq_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_DadM4Hhq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_HFD0N3fH_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_HFD0N3fH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_HJglZzAv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HFD0N3fH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_HFD0N3fH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_r2rEPl15_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_NZyjPvFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hoYmEUzQ, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_AK5vu7V8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HUT2TAdW, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_q3elWbyb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_SSnEOiXN_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_0ncQGqH7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_5iRqFO9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_SSnEOiXN_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_0ncQGqH7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_201oEMIy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_SSnEOiXN_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_0ncQGqH7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Z5yQFFE5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_SSnEOiXN_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_0ncQGqH7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_HXJvfHsE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_SSnEOiXN_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_0ncQGqH7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_P6QliDcY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_ILXSFPhB, 0, m, &cVar_ILXSFPhB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_HLejJQcI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_seY2LPY7, 0, m, &cVar_seY2LPY7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_45zUKSd6, 0, m, &cVar_45zUKSd6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MJo4YCVh, 0, m, &cVar_MJo4YCVh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_9Ehgjmjb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_NZFs7ZyI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_EFxL82Db_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_NZFs7ZyI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_3nOkCdxm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_NZFs7ZyI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_OhYTwle5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_NZFs7ZyI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_bfIVbpDT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gVFrC7dK, 0, m, &cVar_gVFrC7dK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eQj7P2tl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JnMV7MZa, 0, m, &cVar_JnMV7MZa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YpILuSoK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1utfuWq1, 0, m, &cVar_1utfuWq1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_uTXxA7mj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_S2YbT5Bl_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_8ER2YznA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_S2YbT5Bl_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_SgPTrPQ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_S2YbT5Bl_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_A9K3sUBe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_S2YbT5Bl_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_t6H8sKkW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tKWt2ajs, 0, m, &cVar_tKWt2ajs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3DNt0vgD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bnh68LGW, 0, m, &cVar_bnh68LGW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CrG1r3Tx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AMlioFPJ, 0, m, &cVar_AMlioFPJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_5tZwspV8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_5jA0fbtP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_f4uVIEbf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_5jA0fbtP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_ZDZ9H9tj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_5jA0fbtP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_1BcecEjD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_5jA0fbtP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_ptmgPi8z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_smYM9KJH, 0, m, &cVar_smYM9KJH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wz1qicUy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Hu8EM7Hg, 0, m, &cVar_Hu8EM7Hg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qUa5sWx3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_clezGTKR, 0, m, &cVar_clezGTKR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_R7nSVpl3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_seY2LPY7, 0, m, &cVar_seY2LPY7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_KdWEb5Q9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_45zUKSd6, 0, m, &cVar_45zUKSd6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_x8n1LDRa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MJo4YCVh, 0, m, &cVar_MJo4YCVh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_TJeSYfYU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7hJyqIRa, 0, m, &cVar_7hJyqIRa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_eV2OhUJs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UxW7UVDN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_anYA5mMH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_6AVETlxc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sIeeAK63_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9tN1GdOw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Qq2YZgHS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_yOgjppCU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xnoRpFRj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nwS977ax_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rIQ342P5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_ZUyoLbE2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gBTLOuNR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IQcl9pPs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_we8MrJOK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Mujgqiqa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wDyKmpOq_sendMessage(_c, 0, m);
  cMsg_uFDV7Pmi_sendMessage(_c, 0, m);
  cMsg_2r4S7rxl_sendMessage(_c, 0, m);
  cMsg_RHLR2iDC_sendMessage(_c, 0, m);
  cMsg_L5oaNE6x_sendMessage(_c, 0, m);
  cMsg_utKYx5pJ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_85clalx0, 0, m, &cVar_85clalx0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7hJyqIRa, 0, m, &cVar_7hJyqIRa_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_t1G2JKG0, 0, m, &cVar_t1G2JKG0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RhIBlrJS, 0, m, &cVar_RhIBlrJS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tUJulrVF, 0, m, &cVar_tUJulrVF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_UqS0h04a, 0, m, &cVar_UqS0h04a_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_R2XDudXA, 0, m, &cVar_R2XDudXA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JKBYhmm8, 0, m, &cVar_JKBYhmm8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yZheHYAU, 0, m, &cVar_yZheHYAU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MRaM30jw, 0, m, &cVar_MRaM30jw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_b4Neq8TV, 0, m, &cVar_b4Neq8TV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KRLisLj8, 0, m, &cVar_KRLisLj8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0iYcrJUr, 0, m, &cVar_0iYcrJUr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yRQkWDAW, 0, m, &cVar_yRQkWDAW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_T29lSpyH, 0, m, &cVar_T29lSpyH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_00slYsaz, 0, m, &cVar_00slYsaz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ACgbwoi4, 0, m, &cVar_ACgbwoi4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_if1PZSMR, 0, m, &cVar_if1PZSMR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mHH8JuHL, 0, m, &cVar_mHH8JuHL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JrDMldfC, 0, m, &cVar_JrDMldfC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5ThPzORN, 0, m, &cVar_5ThPzORN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ln71GCMl, 0, m, &cVar_ln71GCMl_sendMessage);
  cMsg_nJKwzcGT_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_XFYEVGHw, 0, m, &cVar_XFYEVGHw_sendMessage);
  cMsg_qoSEoF7T_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_eZz5MX1Z, 0, m, &cVar_eZz5MX1Z_sendMessage);
  cMsg_8b1gSw8w_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_37gBMdge, 0, m, &cVar_37gBMdge_sendMessage);
  cMsg_3wEkYHNT_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_7AfRTEIu, 0, m, &cVar_7AfRTEIu_sendMessage);
  cMsg_oxcVBfyn_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_CYZ8r3B0, 0, m, &cVar_CYZ8r3B0_sendMessage);
  cMsg_xBXcz0av_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_wkJf00bk, 0, m, &cVar_wkJf00bk_sendMessage);
  cMsg_NKIp07hU_sendMessage(_c, 0, m);
  cMsg_K7Ka3fP9_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ZDVTHBF0, 0, m, &cVar_ZDVTHBF0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6cn2f5Rv, 0, m, &cVar_6cn2f5Rv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BYGLEnC6, 0, m, &cVar_BYGLEnC6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xVwvHsDs, 0, m, &cVar_xVwvHsDs_sendMessage);
  cMsg_7I3YwioG_sendMessage(_c, 0, m);
  cMsg_yPdpj9Mc_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_mzs9ng0B, 0, m, &cVar_mzs9ng0B_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZHWMDjRh, 0, m, &cVar_ZHWMDjRh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_v4wh0Ziv, 0, m, &cVar_v4wh0Ziv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bNABAef4, 0, m, &cVar_bNABAef4_sendMessage);
  cMsg_GH1bpU5e_sendMessage(_c, 0, m);
  cMsg_N65GHMll_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_lTPBWCdW, 0, m, &cVar_lTPBWCdW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tX5uB8t6, 0, m, &cVar_tX5uB8t6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nzrziBGS, 0, m, &cVar_nzrziBGS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_HJglZzAv, 0, m, &cVar_HJglZzAv_sendMessage);
  cMsg_HLejJQcI_sendMessage(_c, 0, m);
  cMsg_P6QliDcY_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_dfMh03Wz, 0, m, &cVar_dfMh03Wz_sendMessage);
  cMsg_XdeFfpTh_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Td7Gkmr7, 0, m, &cVar_Td7Gkmr7_sendMessage);
  cMsg_P9wkoc9S_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_SXFFteIL, 0, m, &cVar_SXFFteIL_sendMessage);
  cMsg_QZaCEKHH_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_8KdTyqe7, 0, m, &cVar_8KdTyqe7_sendMessage);
  cMsg_jPd1EQsJ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_IA5A2U44, 0, m, &cVar_IA5A2U44_sendMessage);
  cMsg_O1HWoUYX_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Y3q7XLHk, 0, m, &cVar_Y3q7XLHk_sendMessage);
  cMsg_vvzLccHU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_KuldcLmh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZkYgtK0K, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZkYgtK0K_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_obf9exG9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_bqQZBIRp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_0ymE4Cwe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_GBINGNEd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_CqSPT8Qm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_bzPHzthc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Icp498mt_sendMessage);
  cMsg_4oeODpYP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_AdURBmyo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lASL9QkA, HV_BINOP_MULTIPLY, 0, m, &cBinop_lASL9QkA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_mpIClhsL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_bklc5W2D_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_CW7zqlyo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YCtuiaut, HV_BINOP_MULTIPLY, 1, m, &cBinop_YCtuiaut_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_UZcRbIV9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ULgr3cud_sendMessage);
  cMsg_hZqkM545_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_rqJJ1gSt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HRIF1mpM, HV_BINOP_MULTIPLY, 0, m, &cBinop_HRIF1mpM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_SEnG2PZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hBrMwT5K_sendMessage(_c, 0, m);
  cMsg_bOjmZud3_sendMessage(_c, 0, m);
  cMsg_7kxuw08h_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_at2VCn1u_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_xGsLeFuP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_54FzBVlf_sendMessage);
  cMsg_hJw13lGE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_NfbA0M8R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tUJulrVF, 0, m, &cVar_tUJulrVF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_VoUCMCif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Mt4Qtu0g_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VTw2lEdW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_uO5NjQaD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_j6Ac0H98_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6nyoiJiU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FBcWbFUQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_02PNQ4jX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ax2gzxZp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BCpqIXZN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BhOwUkE3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_DsuyVb0v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zNpxPkAH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_m4vqagBK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LDbFqicA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_7neyIP7L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XVmWVm6C, HV_BINOP_MULTIPLY, 0, m, &cBinop_XVmWVm6C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_VN1SwWov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_cXHtQGkN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_KxBn1lnd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_UFIAcK54_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_zPVxKvL3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Ap026MqY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_J2EHrrKB_sendMessage);
  cMsg_oHr9YDQB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_2yJDQU8R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tV7Ee1Vt, HV_BINOP_MULTIPLY, 0, m, &cBinop_tV7Ee1Vt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_sDdzILNU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_YLgIQzH3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Nt4zBirt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a5blsDCX, HV_BINOP_MULTIPLY, 1, m, &cBinop_a5blsDCX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_kq6cjIP9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_xQnRJskL_sendMessage);
  cMsg_OelfOI6Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_tPAgd0Eu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_unwdamnY, HV_BINOP_MULTIPLY, 0, m, &cBinop_unwdamnY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Tr2UmoBy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ByhIsGKX_sendMessage(_c, 0, m);
  cMsg_IOtaqWmK_sendMessage(_c, 0, m);
  cMsg_F6gkLd3d_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_RiDMJ4jp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_DWRBdvb8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_TWuHyRLT_sendMessage);
  cMsg_moSmmCjp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_0xICrInX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ILXSFPhB, 0, m, &cVar_ILXSFPhB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_x0yQcVn7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_bfIVbpDT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_FNqR7SPw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_eQj7P2tl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_jfYPXaIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9JJSau5p, 0, m, &cVar_9JJSau5p_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_wmkKMNyr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_YpILuSoK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_2EDG4QjG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_t6H8sKkW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Ona5TNl7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_3DNt0vgD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_6zFVunh5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HLZRSZri, 0, m, &cVar_HLZRSZri_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_W5PUPxVe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_CrG1r3Tx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_gYfE6U9B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_ptmgPi8z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_TBhNLEF2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_wz1qicUy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_jouQAKBA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Oz0vNkfe, 0, m, &cVar_Oz0vNkfe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_JER2KDT1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_qUa5sWx3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_CwzzB1GA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_yFpUjNiK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_EShcuGGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_urMVncEH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_hBiF29Ml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_3oDTXjqd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_WDo5H596_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ZIKadSao_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_pYfDZZVn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_p8KPC5s5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_tTyhOArW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ZTUSl10S_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_d2pC8NtJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_rNJlCNJ8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Xq6jlpjh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_FIYqgMhs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Ks4C5tR6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_3UwCYN6G_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_S24bjmur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_hY65ZaRg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_r2rEPl15_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_owx52ADh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_ZpU0P97T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_glmnDYkC_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_FL3NGR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_jurx6EIB, VOf(Bf0));
    __hv_line_f(&sLine_EUmf9ANc, VOf(Bf1));
    __hv_line_f(&sLine_RuzPx7Z9, VOf(Bf2));
    __hv_line_f(&sLine_FrngpOrg, VOf(Bf3));
    __hv_line_f(&sLine_SVa9Anlu, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_YVqHOVm7, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_bb3zrCiZ, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_41u3hJH9, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_3pJa7VOx, VOf(Bf1));
    __hv_line_f(&sLine_KkIWiYKr, VOf(Bf0));
    __hv_line_f(&sLine_N7LOpir6, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_GaBq8qZy, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_KWNJJsPO, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_tIpIn8HP, VOf(Bf5));
    __hv_line_f(&sLine_ow1augDd, VOf(Bf1));
    __hv_line_f(&sLine_dHcqEDuZ, VOf(Bf2));
    __hv_line_f(&sLine_TiXqE19e, VOf(Bf4));
    __hv_line_f(&sLine_PKPN8mEC, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_LwupsrmM, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_iGARSpqS, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_Ywq6AxvP, VOf(Bf6));
    __hv_line_f(&sLine_AVUbRAag, VOf(Bf2));
    __hv_line_f(&sLine_zdLfJnDu, VOf(Bf1));
    __hv_line_f(&sLine_1wocVNbL, VOf(Bf5));
    __hv_line_f(&sLine_3IayYz1c, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_r15jLAC4, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_53TgzYsS, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_yHCuHwZp, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_MQYyz720, VOf(Bf2));
    __hv_line_f(&sLine_uqtqW54G, VOf(Bf6));
    __hv_line_f(&sLine_8ujU2d8E, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_QpeDGUDZ, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_dgz8F2dt, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_PNKDZY61, VOf(Bf8));
    __hv_line_f(&sLine_3cH4PAfL, VOf(Bf2));
    __hv_line_f(&sLine_QgPUefYU, VOf(Bf1));
    __hv_line_f(&sLine_JeYDHWuI, VOf(Bf7));
    __hv_line_f(&sLine_EX2dHiPm, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_27NU34l5, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_niiSCNdH, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_if2KQ2Kj, VOf(Bf9));
    __hv_phasor_k_f(&sPhasor_LDEIBBDI, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf8), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_Er9mFktG, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf10), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf2), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf1), VIf(Bf10), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_neg_f(VIf(Bf1), VOf(Bf8));
    __hv_add_f(VIf(Bf8), VIf(Bf10), VOf(Bf8));
    __hv_varread_f(&sVarf_Ahi3MdNM, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_B1eu3pPg, VOf(Bf8));
    __hv_rpole_f(&sRPole_k8x01EiG, VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_fN3kf1uO, VOf(Bf1));
    __hv_mul_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_cBIrdxD2, VOf(Bf10));
    __hv_rpole_f(&sRPole_3CRoBBbM, VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_tabhead_f(&sTabhead_5M8UKNCx, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf2), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_mDjiCuNu, VOf(Bf1));
    __hv_mul_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_3h7z1rqd, VOf(Bf10));
    __hv_min_f(VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf2));
    __hv_varread_f(&sVarf_lqdZnbMS, VOf(Bf10));
    __hv_zero_f(VOf(Bf11));
    __hv_lt_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_and_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_cast_fi(VIf(Bf11), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_TTE6AIQX, VIi(Bi1), VOf(Bf11));
    __hv_tabread_if(&sTabread_TcUNA81x, VIi(Bi0), VOf(Bf10));
    __hv_sub_f(VIf(Bf11), VIf(Bf10), VOf(Bf11));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf11), VIf(Bf2), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_kiiq6Xfo, VOf(Bf2));
    __hv_mul_f(VIf(Bf10), VIf(Bf2), VOf(Bf11));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_tabhead_f(&sTabhead_uNZDkW1U, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_MdRe3iAQ, VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_msnUTrtq, VOf(Bf8));
    __hv_min_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf12), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf12));
    __hv_varread_f(&sVarf_4xjwMElb, VOf(Bf8));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf8), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_C1dScRyq, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_oQPWYu2s, VIi(Bi0), VOf(Bf8));
    __hv_sub_f(VIf(Bf13), VIf(Bf8), VOf(Bf13));
    __hv_sub_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf8), VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf2));
    __hv_fma_f(VIf(Bf9), VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_9DPu3hse, VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_Qdm35qSU, VIf(Bf5));
    __hv_fma_f(VIf(Bf10), VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_FdRymPeH, VIf(Bf3));
    __hv_varwrite_f(&sVarf_tmHmWHLY, VIf(Bf11));
    __hv_line_f(&sLine_DcN9K9V8, VOf(Bf11));
    __hv_phasor_k_f(&sPhasor_pNHHKuqg, VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_abs_f(VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf3), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf9), VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_sZXWE02r, VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf5), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf3));
    __hv_mul_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_neg_f(VIf(Bf3), VOf(Bf10));
    __hv_add_f(VIf(Bf10), VIf(Bf5), VOf(Bf10));
    __hv_varread_f(&sVarf_jUByUiC0, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_AR1GpwfO, VOf(Bf10));
    __hv_rpole_f(&sRPole_ar0tyJnb, VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_G8cnrmSN, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_JRcDXLjU, VOf(Bf5));
    __hv_rpole_f(&sRPole_2HzMCdqe, VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_tabhead_f(&sTabhead_bMlQmt8u, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf9), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_SuvAPki8, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_Slkl1VYZ, VOf(Bf5));
    __hv_min_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf9));
    __hv_varread_f(&sVarf_BCV3gzcv, VOf(Bf5));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_laRjgD5y, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_GdUG6gMm, VIi(Bi0), VOf(Bf5));
    __hv_sub_f(VIf(Bf8), VIf(Bf5), VOf(Bf8));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf8), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_HePiWqR1, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf8));
    __hv_fma_f(VIf(Bf0), VIf(Bf11), VIf(Bf8), VOf(Bf8));
    __hv_tabhead_f(&sTabhead_oSyBAf7h, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_0jsZbEe2, VOf(Bf3));
    __hv_mul_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_vrUgYlqu, VOf(Bf10));
    __hv_min_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf12));
    __hv_varread_f(&sVarf_Nik7EkMI, VOf(Bf10));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_0jv1OnUW, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_0ekjSuyP, VIi(Bi0), VOf(Bf10));
    __hv_sub_f(VIf(Bf13), VIf(Bf10), VOf(Bf13));
    __hv_sub_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf9));
    __hv_fma_f(VIf(Bf11), VIf(Bf6), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_sQJBthcd, VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_tabwrite_f(&sTabwrite_BQqfwjtC, VIf(Bf6));
    __hv_fma_f(VIf(Bf5), VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_pVuivMdQ, VIf(Bf0));
    __hv_varwrite_f(&sVarf_jb5j9Dul, VIf(Bf8));
    __hv_line_f(&sLine_HUT2TAdW, VOf(Bf8));
    __hv_phasor_k_f(&sPhasor_OO5lEkFL, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_abs_f(VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf11), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_NiMhLQGl, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_neg_f(VIf(Bf0), VOf(Bf5));
    __hv_add_f(VIf(Bf5), VIf(Bf6), VOf(Bf5));
    __hv_varread_f(&sVarf_xb6P6MFO, VOf(Bf11));
    __hv_mul_f(VIf(Bf5), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_5NVBgRkf, VOf(Bf5));
    __hv_rpole_f(&sRPole_WHUUoE7L, VIf(Bf11), VIf(Bf5), VOf(Bf5));
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_Hk5mAGKl, VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_53ckMoCZ, VOf(Bf6));
    __hv_rpole_f(&sRPole_vM1tfxS3, VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_tabhead_f(&sTabhead_ITkCfxnG, VOf(Bf0));
    __hv_var_k_f_r(VOf(Bf11), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_Phqr5L9W, VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_4HQPB4a7, VOf(Bf6));
    __hv_min_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_zero_f(VOf(Bf0));
    __hv_max_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_sub_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_floor_f(VIf(Bf0), VOf(Bf11));
    __hv_varread_f(&sVarf_R6VDCSVA, VOf(Bf6));
    __hv_zero_f(VOf(Bf10));
    __hv_lt_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_and_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_cast_fi(VIf(Bf10), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_M1CxJwDS, VIi(Bi1), VOf(Bf10));
    __hv_tabread_if(&sTabread_0knoswvn, VIi(Bi0), VOf(Bf6));
    __hv_sub_f(VIf(Bf10), VIf(Bf6), VOf(Bf10));
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_fma_f(VIf(Bf10), VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_hoYmEUzQ, VOf(Bf11));
    __hv_mul_f(VIf(Bf6), VIf(Bf11), VOf(Bf10));
    __hv_fma_f(VIf(Bf4), VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_tabhead_f(&sTabhead_xxOWQeQz, VOf(Bf0));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf0), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_IDZopqVd, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_08hnKi59, VOf(Bf5));
    __hv_min_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_zero_f(VOf(Bf0));
    __hv_max_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_sub_f(VIf(Bf12), VIf(Bf0), VOf(Bf0));
    __hv_floor_f(VIf(Bf0), VOf(Bf12));
    __hv_varread_f(&sVarf_S1uJUz2k, VOf(Bf5));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf5), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_7fUZjlQh, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_WVnrwdYv, VIi(Bi0), VOf(Bf5));
    __hv_sub_f(VIf(Bf13), VIf(Bf5), VOf(Bf13));
    __hv_sub_f(VIf(Bf0), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf11), VIf(Bf5), VOf(Bf11));
    __hv_fma_f(VIf(Bf8), VIf(Bf7), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_3KG0iEj1, VOf(Bf8));
    __hv_fma_f(VIf(Bf8), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_S52q2reb, VIf(Bf7));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_3olcHRWz, VIf(Bf4));
    __hv_varwrite_f(&sVarf_gxhma5Va, VIf(Bf10));
    __hv_varwrite_f(&sVarf_zq6ZOvAM, VIf(Bf2));
    __hv_varwrite_f(&sVarf_3kscW9n9, VIf(Bf9));
    __hv_varwrite_f(&sVarf_P80tBW52, VIf(Bf11));
    __hv_varread_f(&sVarf_zq6ZOvAM, VOf(Bf11));
    __hv_varread_f(&sVarf_3kscW9n9, VOf(Bf9));
    __hv_varread_f(&sVarf_P80tBW52, VOf(Bf2));
    __hv_add_f(VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf11), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));
    __hv_varread_f(&sVarf_tmHmWHLY, VOf(Bf2));
    __hv_varread_f(&sVarf_jb5j9Dul, VOf(Bf11));
    __hv_varread_f(&sVarf_gxhma5Va, VOf(Bf9));
    __hv_add_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf9), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_FL3NGR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_FL3NGR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
